# coding: utf-8

"""
    aptos-api

    The aptos-api provider  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""

from datetime import date, datetime  # noqa: F401
import decimal  # noqa: F401
import functools  # noqa: F401
import io  # noqa: F401
import re  # noqa: F401
import typing  # noqa: F401
import typing_extensions  # noqa: F401
import uuid  # noqa: F401

import frozendict  # noqa: F401

from openapi_aptos_api import schemas  # noqa: F401


class NFTCollectionItemResponse(
    schemas.DictSchema
):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """


    class MetaOapg:
        required = {
            "last_transaction_version",
            "last_transaction_timestamp",
            "metadata_uri",
            "description",
            "uri_mutable",
            "supply",
            "description_mutable",
            "table_handle",
            "collection_data_id_hash",
            "maximum_mutable",
            "creator_address",
            "maximum",
            "collection_name",
        }
        
        class properties:
            
            
            class collection_data_id_hash(
                schemas.StrSchema
            ):
            
            
                class MetaOapg:
                    max_length = 64
                    min_length = 64
            
            
            class collection_name(
                schemas.StrSchema
            ):
            
            
                class MetaOapg:
                    max_length = 128
                    min_length = 1
            
            
            class creator_address(
                schemas.StrSchema
            ):
            
            
                class MetaOapg:
                    max_length = 66
                    min_length = 66
            description = schemas.StrSchema
            description_mutable = schemas.BoolSchema
            last_transaction_timestamp = schemas.StrSchema
            last_transaction_version = schemas.StrSchema
            maximum = schemas.StrSchema
            maximum_mutable = schemas.BoolSchema
            metadata_uri = schemas.StrSchema
            supply = schemas.StrSchema
            table_handle = schemas.StrSchema
            uri_mutable = schemas.BoolSchema
            __annotations__ = {
                "collection_data_id_hash": collection_data_id_hash,
                "collection_name": collection_name,
                "creator_address": creator_address,
                "description": description,
                "description_mutable": description_mutable,
                "last_transaction_timestamp": last_transaction_timestamp,
                "last_transaction_version": last_transaction_version,
                "maximum": maximum,
                "maximum_mutable": maximum_mutable,
                "metadata_uri": metadata_uri,
                "supply": supply,
                "table_handle": table_handle,
                "uri_mutable": uri_mutable,
            }
    
    last_transaction_version: MetaOapg.properties.last_transaction_version
    last_transaction_timestamp: MetaOapg.properties.last_transaction_timestamp
    metadata_uri: MetaOapg.properties.metadata_uri
    description: MetaOapg.properties.description
    uri_mutable: MetaOapg.properties.uri_mutable
    supply: MetaOapg.properties.supply
    description_mutable: MetaOapg.properties.description_mutable
    table_handle: MetaOapg.properties.table_handle
    collection_data_id_hash: MetaOapg.properties.collection_data_id_hash
    maximum_mutable: MetaOapg.properties.maximum_mutable
    creator_address: MetaOapg.properties.creator_address
    maximum: MetaOapg.properties.maximum
    collection_name: MetaOapg.properties.collection_name
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["collection_data_id_hash"]) -> MetaOapg.properties.collection_data_id_hash: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["collection_name"]) -> MetaOapg.properties.collection_name: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["creator_address"]) -> MetaOapg.properties.creator_address: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["description"]) -> MetaOapg.properties.description: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["description_mutable"]) -> MetaOapg.properties.description_mutable: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["last_transaction_timestamp"]) -> MetaOapg.properties.last_transaction_timestamp: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["last_transaction_version"]) -> MetaOapg.properties.last_transaction_version: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["maximum"]) -> MetaOapg.properties.maximum: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["maximum_mutable"]) -> MetaOapg.properties.maximum_mutable: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["metadata_uri"]) -> MetaOapg.properties.metadata_uri: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["supply"]) -> MetaOapg.properties.supply: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["table_handle"]) -> MetaOapg.properties.table_handle: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["uri_mutable"]) -> MetaOapg.properties.uri_mutable: ...
    
    @typing.overload
    def __getitem__(self, name: str) -> schemas.UnsetAnyTypeSchema: ...
    
    def __getitem__(self, name: typing.Union[typing_extensions.Literal["collection_data_id_hash", "collection_name", "creator_address", "description", "description_mutable", "last_transaction_timestamp", "last_transaction_version", "maximum", "maximum_mutable", "metadata_uri", "supply", "table_handle", "uri_mutable", ], str]):
        # dict_instance[name] accessor
        return super().__getitem__(name)
    
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["collection_data_id_hash"]) -> MetaOapg.properties.collection_data_id_hash: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["collection_name"]) -> MetaOapg.properties.collection_name: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["creator_address"]) -> MetaOapg.properties.creator_address: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["description"]) -> MetaOapg.properties.description: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["description_mutable"]) -> MetaOapg.properties.description_mutable: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["last_transaction_timestamp"]) -> MetaOapg.properties.last_transaction_timestamp: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["last_transaction_version"]) -> MetaOapg.properties.last_transaction_version: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["maximum"]) -> MetaOapg.properties.maximum: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["maximum_mutable"]) -> MetaOapg.properties.maximum_mutable: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["metadata_uri"]) -> MetaOapg.properties.metadata_uri: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["supply"]) -> MetaOapg.properties.supply: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["table_handle"]) -> MetaOapg.properties.table_handle: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["uri_mutable"]) -> MetaOapg.properties.uri_mutable: ...
    
    @typing.overload
    def get_item_oapg(self, name: str) -> typing.Union[schemas.UnsetAnyTypeSchema, schemas.Unset]: ...
    
    def get_item_oapg(self, name: typing.Union[typing_extensions.Literal["collection_data_id_hash", "collection_name", "creator_address", "description", "description_mutable", "last_transaction_timestamp", "last_transaction_version", "maximum", "maximum_mutable", "metadata_uri", "supply", "table_handle", "uri_mutable", ], str]):
        return super().get_item_oapg(name)
    

    def __new__(
        cls,
        *args: typing.Union[dict, frozendict.frozendict, ],
        last_transaction_version: typing.Union[MetaOapg.properties.last_transaction_version, str, ],
        last_transaction_timestamp: typing.Union[MetaOapg.properties.last_transaction_timestamp, str, ],
        metadata_uri: typing.Union[MetaOapg.properties.metadata_uri, str, ],
        description: typing.Union[MetaOapg.properties.description, str, ],
        uri_mutable: typing.Union[MetaOapg.properties.uri_mutable, bool, ],
        supply: typing.Union[MetaOapg.properties.supply, str, ],
        description_mutable: typing.Union[MetaOapg.properties.description_mutable, bool, ],
        table_handle: typing.Union[MetaOapg.properties.table_handle, str, ],
        collection_data_id_hash: typing.Union[MetaOapg.properties.collection_data_id_hash, str, ],
        maximum_mutable: typing.Union[MetaOapg.properties.maximum_mutable, bool, ],
        creator_address: typing.Union[MetaOapg.properties.creator_address, str, ],
        maximum: typing.Union[MetaOapg.properties.maximum, str, ],
        collection_name: typing.Union[MetaOapg.properties.collection_name, str, ],
        _configuration: typing.Optional[schemas.Configuration] = None,
        **kwargs: typing.Union[schemas.AnyTypeSchema, dict, frozendict.frozendict, str, date, datetime, uuid.UUID, int, float, decimal.Decimal, None, list, tuple, bytes],
    ) -> 'NFTCollectionItemResponse':
        return super().__new__(
            cls,
            *args,
            last_transaction_version=last_transaction_version,
            last_transaction_timestamp=last_transaction_timestamp,
            metadata_uri=metadata_uri,
            description=description,
            uri_mutable=uri_mutable,
            supply=supply,
            description_mutable=description_mutable,
            table_handle=table_handle,
            collection_data_id_hash=collection_data_id_hash,
            maximum_mutable=maximum_mutable,
            creator_address=creator_address,
            maximum=maximum,
            collection_name=collection_name,
            _configuration=_configuration,
            **kwargs,
        )



# coding: utf-8

"""
    Streams Api

    API that provides access to Moralis Streams  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""

from datetime import date, datetime  # noqa: F401
import decimal  # noqa: F401
import functools  # noqa: F401
import io  # noqa: F401
import re  # noqa: F401
import typing  # noqa: F401
import typing_extensions  # noqa: F401
import uuid  # noqa: F401

import frozendict  # noqa: F401

from openapi_streams import schemas  # noqa: F401


class InternalTransaction(
    schemas.DictSchema
):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """


    class MetaOapg:
        required = {
            "gas",
            "from",
            "to",
            "value",
            "transactionHash",
        }
        
        class properties:
            
            
            class _from(
                schemas.StrBase,
                schemas.NoneBase,
                schemas.Schema,
                schemas.NoneStrMixin
            ):
            
            
                def __new__(
                    cls,
                    *args: typing.Union[None, str, ],
                    _configuration: typing.Optional[schemas.Configuration] = None,
                ) -> '_from':
                    return super().__new__(
                        cls,
                        *args,
                        _configuration=_configuration,
                    )
            
            
            class to(
                schemas.StrBase,
                schemas.NoneBase,
                schemas.Schema,
                schemas.NoneStrMixin
            ):
            
            
                def __new__(
                    cls,
                    *args: typing.Union[None, str, ],
                    _configuration: typing.Optional[schemas.Configuration] = None,
                ) -> 'to':
                    return super().__new__(
                        cls,
                        *args,
                        _configuration=_configuration,
                    )
            
            
            class value(
                schemas.StrBase,
                schemas.NoneBase,
                schemas.Schema,
                schemas.NoneStrMixin
            ):
            
            
                def __new__(
                    cls,
                    *args: typing.Union[None, str, ],
                    _configuration: typing.Optional[schemas.Configuration] = None,
                ) -> 'value':
                    return super().__new__(
                        cls,
                        *args,
                        _configuration=_configuration,
                    )
            transactionHash = schemas.StrSchema
            
            
            class gas(
                schemas.StrBase,
                schemas.NoneBase,
                schemas.Schema,
                schemas.NoneStrMixin
            ):
            
            
                def __new__(
                    cls,
                    *args: typing.Union[None, str, ],
                    _configuration: typing.Optional[schemas.Configuration] = None,
                ) -> 'gas':
                    return super().__new__(
                        cls,
                        *args,
                        _configuration=_configuration,
                    )
            __annotations__ = {
                "from": _from,
                "to": to,
                "value": value,
                "transactionHash": transactionHash,
                "gas": gas,
            }
        additional_properties = schemas.NotAnyTypeSchema
    
    gas: MetaOapg.properties.gas
    to: MetaOapg.properties.to
    value: MetaOapg.properties.value
    transactionHash: MetaOapg.properties.transactionHash
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["gas"]) -> MetaOapg.properties.gas: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["from"]) -> MetaOapg.properties._from: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["to"]) -> MetaOapg.properties.to: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["value"]) -> MetaOapg.properties.value: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["transactionHash"]) -> MetaOapg.properties.transactionHash: ...
    
    def __getitem__(self, name: typing.Union[typing_extensions.Literal["gas"], typing_extensions.Literal["from"], typing_extensions.Literal["to"], typing_extensions.Literal["value"], typing_extensions.Literal["transactionHash"], ]):
        # dict_instance[name] accessor
        return super().__getitem__(name)
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["gas"]) -> MetaOapg.properties.gas: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["from"]) -> MetaOapg.properties._from: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["to"]) -> MetaOapg.properties.to: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["value"]) -> MetaOapg.properties.value: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["transactionHash"]) -> MetaOapg.properties.transactionHash: ...
    
    def get_item_oapg(self, name: typing.Union[typing_extensions.Literal["gas"], typing_extensions.Literal["from"], typing_extensions.Literal["to"], typing_extensions.Literal["value"], typing_extensions.Literal["transactionHash"], ]):
        return super().get_item_oapg(name)

    def __new__(
        cls,
        *args: typing.Union[dict, frozendict.frozendict, ],
        gas: typing.Union[MetaOapg.properties.gas, None, str, ],
        to: typing.Union[MetaOapg.properties.to, None, str, ],
        value: typing.Union[MetaOapg.properties.value, None, str, ],
        transactionHash: typing.Union[MetaOapg.properties.transactionHash, str, ],
        _configuration: typing.Optional[schemas.Configuration] = None,
    ) -> 'InternalTransaction':
        return super().__new__(
            cls,
            *args,
            gas=gas,
            to=to,
            value=value,
            transactionHash=transactionHash,
            _configuration=_configuration,
        )



# coding: utf-8

"""
    aptos-api

    The aptos-api provider  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""

from openapi_aptos_api.paths.nfts_collections_collection_data_id_hash_owners.get import GetNftOwnersByCollection
from openapi_aptos_api.paths.nfts_owners.get import GetNftOwnersByTokens
from openapi_aptos_api.paths.nfts_collections_collection_data_id_hash_owners_list.get import GetNftOwnersOfCollection
from openapi_aptos_api.paths.nfts_transfers_collections_collection_data_id_hash.get import GetNftTransfersByCollection
from openapi_aptos_api.paths.nfts_transfers_creators.get import GetNftTransfersByCreators
from openapi_aptos_api.paths.nfts_transfers.get import GetNftTransfersByIds
from openapi_aptos_api.paths.nfts_transfers_wallets.get import GetNftTransfersByWallets
from openapi_aptos_api.paths.nfts_collections_collection_data_id_hash_tokens.get import GetNftsByCollection
from openapi_aptos_api.paths.nfts_creators.get import GetNftsByCreators
from openapi_aptos_api.paths.nfts.get import GetNftsByIds


class NftsApi(
    GetNftOwnersByCollection,
    GetNftOwnersByTokens,
    GetNftOwnersOfCollection,
    GetNftTransfersByCollection,
    GetNftTransfersByCreators,
    GetNftTransfersByIds,
    GetNftTransfersByWallets,
    GetNftsByCollection,
    GetNftsByCreators,
    GetNftsByIds,
):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """
    pass



# coding: utf-8

# flake8: noqa

# import all models into this package
# if you have many models here with many references from one model to another this may
# raise a RecursionError
# to avoid this, import only the models that you directly need like:
# from from openapi_aptos_api.model.pet import Pet
# or import this package, but before doing it, use:
# import sys
# sys.setrecursionlimit(n)

from openapi_aptos_api.model.bad_request_response import BadRequestResponse
from openapi_aptos_api.model.block import Block
from openapi_aptos_api.model.block_metadata_transaction import BlockMetadataTransaction
from openapi_aptos_api.model.coin_info_dto import CoinInfoDto
from openapi_aptos_api.model.coin_transfer_dto import CoinTransferDto
from openapi_aptos_api.model.current_coin_balance_dto import CurrentCoinBalanceDto
from openapi_aptos_api.model.decoded_table_data import DecodedTableData
from openapi_aptos_api.model.delete_module_change import DeleteModuleChange
from openapi_aptos_api.model.delete_resource_change import DeleteResourceChange
from openapi_aptos_api.model.delete_table_item_change import DeleteTableItemChange
from openapi_aptos_api.model.deleted_table_data import DeletedTableData
from openapi_aptos_api.model.direct_write_set import DirectWriteSet
from openapi_aptos_api.model.ed25519_signature_request import Ed25519SignatureRequest
from openapi_aptos_api.model.encode_submission_request import EncodeSubmissionRequest
from openapi_aptos_api.model.entry_function_payload_request import EntryFunctionPayloadRequest
from openapi_aptos_api.model.estimate_gas_price_result import EstimateGasPriceResult
from openapi_aptos_api.model.generic_type_param import GenericTypeParam
from openapi_aptos_api.model.genesis_transaction import GenesisTransaction
from openapi_aptos_api.model.get_account_module_response import GetAccountModuleResponse
from openapi_aptos_api.model.get_account_resource_response import GetAccountResourceResponse
from openapi_aptos_api.model.get_account_response import GetAccountResponse
from openapi_aptos_api.model.get_coin_balances_by_wallets_response import GetCoinBalancesByWalletsResponse
from openapi_aptos_api.model.get_coin_transfers_by_block_heights_response import GetCoinTransfersByBlockHeightsResponse
from openapi_aptos_api.model.get_coin_transfers_by_coin_type_response import GetCoinTransfersByCoinTypeResponse
from openapi_aptos_api.model.get_coin_transfers_by_owner_addresses_response import GetCoinTransfersByOwnerAddressesResponse
from openapi_aptos_api.model.get_coins_by_creators_response import GetCoinsByCreatorsResponse
from openapi_aptos_api.model.get_coins_by_name_range_response import GetCoinsByNameRangeResponse
from openapi_aptos_api.model.get_coins_by_symbol_range_response import GetCoinsBySymbolRangeResponse
from openapi_aptos_api.model.get_events_by_creation_number_response import GetEventsByCreationNumberResponse
from openapi_aptos_api.model.get_events_by_event_handle_response import GetEventsByEventHandleResponse
from openapi_aptos_api.model.get_historical_coin_balances_by_wallets_response import GetHistoricalCoinBalancesByWalletsResponse
from openapi_aptos_api.model.get_latest_coins_response import GetLatestCoinsResponse
from openapi_aptos_api.model.get_nft_transfers_by_collection_response import GetNFTTransfersByCollectionResponse
from openapi_aptos_api.model.get_nft_transfers_by_creators_response import GetNFTTransfersByCreatorsResponse
from openapi_aptos_api.model.get_top_holders_by_coin_response import GetTopHoldersByCoinResponse
from openapi_aptos_api.model.historical_coin_balance_dto import HistoricalCoinBalanceDto
from openapi_aptos_api.model.module_bundle_payload_request import ModuleBundlePayloadRequest
from openapi_aptos_api.model.module_exposed_function import ModuleExposedFunction
from openapi_aptos_api.model.module_struct import ModuleStruct
from openapi_aptos_api.model.module_struct_field import ModuleStructField
from openapi_aptos_api.model.move_module_abi import MoveModuleAbi
from openapi_aptos_api.model.multi_agent_signature_request import MultiAgentSignatureRequest
from openapi_aptos_api.model.multi_ed25519_signature_request import MultiEd25519SignatureRequest
from openapi_aptos_api.model.nft_collection_item_response import NFTCollectionItemResponse
from openapi_aptos_api.model.nft_collections_by_creator_response import NFTCollectionsByCreatorResponse
from openapi_aptos_api.model.nft_collections_by_name_range_response import NFTCollectionsByNameRangeResponse
from openapi_aptos_api.model.nft_owner_response import NFTOwnerResponse
from openapi_aptos_api.model.nft_owners_by_collection_response import NFTOwnersByCollectionResponse
from openapi_aptos_api.model.nft_owners_by_tokens_response import NFTOwnersByTokensResponse
from openapi_aptos_api.model.nft_owners_of_collection_response import NFTOwnersOfCollectionResponse
from openapi_aptos_api.model.nft_token_response import NFTTokenResponse
from openapi_aptos_api.model.nft_tokens_by_collection_response import NFTTokensByCollectionResponse
from openapi_aptos_api.model.nft_tokens_by_creators_response import NFTTokensByCreatorsResponse
from openapi_aptos_api.model.nft_transfer_response import NFTTransferResponse
from openapi_aptos_api.model.nft_transfers_by_tokens_response import NFTTransfersByTokensResponse
from openapi_aptos_api.model.nft_transfers_by_wallets_response import NFTTransfersByWalletsResponse
from openapi_aptos_api.model.nfts_by_owners_response import NFTsByOwnersResponse
from openapi_aptos_api.model.pending_transaction import PendingTransaction
from openapi_aptos_api.model.script_payload_request import ScriptPayloadRequest
from openapi_aptos_api.model.script_write_set import ScriptWriteSet
from openapi_aptos_api.model.state_checkpoint_transaction import StateCheckpointTransaction
from openapi_aptos_api.model.submit_batch_transaction_result import SubmitBatchTransactionResult
from openapi_aptos_api.model.submit_transaction_request import SubmitTransactionRequest
from openapi_aptos_api.model.transaction_event import TransactionEvent
from openapi_aptos_api.model.transaction_event_guid import TransactionEventGuid
from openapi_aptos_api.model.user_transaction import UserTransaction
from openapi_aptos_api.model.write_module_data import WriteModuleData
from openapi_aptos_api.model.write_or_update_module_change import WriteOrUpdateModuleChange
from openapi_aptos_api.model.write_set_payload import WriteSetPayload
from openapi_aptos_api.model.write_table_change_set_change import WriteTableChangeSetChange



from .get_transaction import get_transaction
from .get_transaction_verbose import get_transaction_verbose
from .get_wallet_transactions import get_wallet_transactions
from .get_wallet_transactions_verbose import get_wallet_transactions_verbose



# coding: utf-8

"""
    aptos-api

    The aptos-api provider  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""

from datetime import date, datetime  # noqa: F401
import decimal  # noqa: F401
import functools  # noqa: F401
import io  # noqa: F401
import re  # noqa: F401
import typing  # noqa: F401
import typing_extensions  # noqa: F401
import uuid  # noqa: F401

import frozendict  # noqa: F401

from openapi_aptos_api import schemas  # noqa: F401


class CoinTransferDto(
    schemas.DictSchema
):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """


    class MetaOapg:
        required = {
            "amount",
            "coin_type",
            "is_transaction_success",
            "event_sequence_number",
            "owner_address",
            "transaction_timestamp",
            "block_height",
            "event_creation_number",
            "event_account_address",
            "activity_type",
            "entry_function_id_str",
            "transaction_version",
            "is_gas_fee",
        }
        
        class properties:
            
            
            class activity_type(
                schemas.StrSchema
            ):
            
            
                class MetaOapg:
                    max_length = 200
                    min_length = 1
            
            
            class amount(
                schemas.StrSchema
            ):
            
            
                class MetaOapg:
                    max_length = 200
                    min_length = 1
            
            
            class block_height(
                schemas.StrSchema
            ):
            
            
                class MetaOapg:
                    max_length = 200
                    min_length = 1
            
            
            class coin_type(
                schemas.StrSchema
            ):
            
            
                class MetaOapg:
                    max_length = 5000
                    min_length = 1
            
            
            class entry_function_id_str(
                schemas.StrBase,
                schemas.NoneBase,
                schemas.Schema,
                schemas.NoneStrMixin
            ):
            
            
                class MetaOapg:
                    max_length = 100
                    min_length = 1
            
            
                def __new__(
                    cls,
                    *args: typing.Union[None, str, ],
                    _configuration: typing.Optional[schemas.Configuration] = None,
                ) -> 'entry_function_id_str':
                    return super().__new__(
                        cls,
                        *args,
                        _configuration=_configuration,
                    )
            
            
            class event_account_address(
                schemas.StrSchema
            ):
            
            
                class MetaOapg:
                    max_length = 66
                    min_length = 66
            
            
            class event_creation_number(
                schemas.StrSchema
            ):
            
            
                class MetaOapg:
                    max_length = 66
                    min_length = 1
            
            
            class event_sequence_number(
                schemas.StrSchema
            ):
            
            
                class MetaOapg:
                    max_length = 66
                    min_length = 1
            is_gas_fee = schemas.BoolSchema
            is_transaction_success = schemas.BoolSchema
            
            
            class owner_address(
                schemas.StrSchema
            ):
            
            
                class MetaOapg:
                    max_length = 66
                    min_length = 66
            transaction_timestamp = schemas.StrSchema
            transaction_version = schemas.StrSchema
            __annotations__ = {
                "activity_type": activity_type,
                "amount": amount,
                "block_height": block_height,
                "coin_type": coin_type,
                "entry_function_id_str": entry_function_id_str,
                "event_account_address": event_account_address,
                "event_creation_number": event_creation_number,
                "event_sequence_number": event_sequence_number,
                "is_gas_fee": is_gas_fee,
                "is_transaction_success": is_transaction_success,
                "owner_address": owner_address,
                "transaction_timestamp": transaction_timestamp,
                "transaction_version": transaction_version,
            }
    
    amount: MetaOapg.properties.amount
    coin_type: MetaOapg.properties.coin_type
    is_transaction_success: MetaOapg.properties.is_transaction_success
    event_sequence_number: MetaOapg.properties.event_sequence_number
    owner_address: MetaOapg.properties.owner_address
    transaction_timestamp: MetaOapg.properties.transaction_timestamp
    block_height: MetaOapg.properties.block_height
    event_creation_number: MetaOapg.properties.event_creation_number
    event_account_address: MetaOapg.properties.event_account_address
    activity_type: MetaOapg.properties.activity_type
    entry_function_id_str: MetaOapg.properties.entry_function_id_str
    transaction_version: MetaOapg.properties.transaction_version
    is_gas_fee: MetaOapg.properties.is_gas_fee
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["activity_type"]) -> MetaOapg.properties.activity_type: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["amount"]) -> MetaOapg.properties.amount: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["block_height"]) -> MetaOapg.properties.block_height: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["coin_type"]) -> MetaOapg.properties.coin_type: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["entry_function_id_str"]) -> MetaOapg.properties.entry_function_id_str: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["event_account_address"]) -> MetaOapg.properties.event_account_address: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["event_creation_number"]) -> MetaOapg.properties.event_creation_number: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["event_sequence_number"]) -> MetaOapg.properties.event_sequence_number: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["is_gas_fee"]) -> MetaOapg.properties.is_gas_fee: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["is_transaction_success"]) -> MetaOapg.properties.is_transaction_success: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["owner_address"]) -> MetaOapg.properties.owner_address: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["transaction_timestamp"]) -> MetaOapg.properties.transaction_timestamp: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["transaction_version"]) -> MetaOapg.properties.transaction_version: ...
    
    @typing.overload
    def __getitem__(self, name: str) -> schemas.UnsetAnyTypeSchema: ...
    
    def __getitem__(self, name: typing.Union[typing_extensions.Literal["activity_type", "amount", "block_height", "coin_type", "entry_function_id_str", "event_account_address", "event_creation_number", "event_sequence_number", "is_gas_fee", "is_transaction_success", "owner_address", "transaction_timestamp", "transaction_version", ], str]):
        # dict_instance[name] accessor
        return super().__getitem__(name)
    
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["activity_type"]) -> MetaOapg.properties.activity_type: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["amount"]) -> MetaOapg.properties.amount: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["block_height"]) -> MetaOapg.properties.block_height: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["coin_type"]) -> MetaOapg.properties.coin_type: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["entry_function_id_str"]) -> MetaOapg.properties.entry_function_id_str: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["event_account_address"]) -> MetaOapg.properties.event_account_address: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["event_creation_number"]) -> MetaOapg.properties.event_creation_number: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["event_sequence_number"]) -> MetaOapg.properties.event_sequence_number: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["is_gas_fee"]) -> MetaOapg.properties.is_gas_fee: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["is_transaction_success"]) -> MetaOapg.properties.is_transaction_success: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["owner_address"]) -> MetaOapg.properties.owner_address: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["transaction_timestamp"]) -> MetaOapg.properties.transaction_timestamp: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["transaction_version"]) -> MetaOapg.properties.transaction_version: ...
    
    @typing.overload
    def get_item_oapg(self, name: str) -> typing.Union[schemas.UnsetAnyTypeSchema, schemas.Unset]: ...
    
    def get_item_oapg(self, name: typing.Union[typing_extensions.Literal["activity_type", "amount", "block_height", "coin_type", "entry_function_id_str", "event_account_address", "event_creation_number", "event_sequence_number", "is_gas_fee", "is_transaction_success", "owner_address", "transaction_timestamp", "transaction_version", ], str]):
        return super().get_item_oapg(name)
    

    def __new__(
        cls,
        *args: typing.Union[dict, frozendict.frozendict, ],
        amount: typing.Union[MetaOapg.properties.amount, str, ],
        coin_type: typing.Union[MetaOapg.properties.coin_type, str, ],
        is_transaction_success: typing.Union[MetaOapg.properties.is_transaction_success, bool, ],
        event_sequence_number: typing.Union[MetaOapg.properties.event_sequence_number, str, ],
        owner_address: typing.Union[MetaOapg.properties.owner_address, str, ],
        transaction_timestamp: typing.Union[MetaOapg.properties.transaction_timestamp, str, ],
        block_height: typing.Union[MetaOapg.properties.block_height, str, ],
        event_creation_number: typing.Union[MetaOapg.properties.event_creation_number, str, ],
        event_account_address: typing.Union[MetaOapg.properties.event_account_address, str, ],
        activity_type: typing.Union[MetaOapg.properties.activity_type, str, ],
        entry_function_id_str: typing.Union[MetaOapg.properties.entry_function_id_str, None, str, ],
        transaction_version: typing.Union[MetaOapg.properties.transaction_version, str, ],
        is_gas_fee: typing.Union[MetaOapg.properties.is_gas_fee, bool, ],
        _configuration: typing.Optional[schemas.Configuration] = None,
        **kwargs: typing.Union[schemas.AnyTypeSchema, dict, frozendict.frozendict, str, date, datetime, uuid.UUID, int, float, decimal.Decimal, None, list, tuple, bytes],
    ) -> 'CoinTransferDto':
        return super().__new__(
            cls,
            *args,
            amount=amount,
            coin_type=coin_type,
            is_transaction_success=is_transaction_success,
            event_sequence_number=event_sequence_number,
            owner_address=owner_address,
            transaction_timestamp=transaction_timestamp,
            block_height=block_height,
            event_creation_number=event_creation_number,
            event_account_address=event_account_address,
            activity_type=activity_type,
            entry_function_id_str=entry_function_id_str,
            transaction_version=transaction_version,
            is_gas_fee=is_gas_fee,
            _configuration=_configuration,
            **kwargs,
        )



# coding: utf-8

"""
    aptos-api

    The aptos-api provider  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""

from datetime import date, datetime  # noqa: F401
import decimal  # noqa: F401
import functools  # noqa: F401
import io  # noqa: F401
import re  # noqa: F401
import typing  # noqa: F401
import typing_extensions  # noqa: F401
import uuid  # noqa: F401

import frozendict  # noqa: F401

from openapi_aptos_api import schemas  # noqa: F401


class DeleteTableItemChange(
    schemas.DictSchema
):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """


    class MetaOapg:
        required = {
            "address",
            "data",
            "state_key_hash",
            "handle",
            "type",
            "key",
        }
        
        class properties:
            type = schemas.StrSchema
            address = schemas.DictSchema
            state_key_hash = schemas.StrSchema
            handle = schemas.DictSchema
            key = schemas.DictSchema
            
            
            class data(
                schemas.ComposedSchema,
            ):
            
            
                class MetaOapg:
                    
                    @classmethod
                    @functools.lru_cache()
                    def all_of(cls):
                        # we need this here to make our import statements work
                        # we must store _composed_schemas in here so the code is only run
                        # when we invoke this method. If we kept this at the class
                        # level we would get an error because the class level
                        # code would be run when this module is imported, and these composed
                        # classes don't exist yet because their module has not finished
                        # loading
                        return [
                            DeletedTableData,
                        ]
            
            
                def __new__(
                    cls,
                    *args: typing.Union[dict, frozendict.frozendict, str, date, datetime, uuid.UUID, int, float, decimal.Decimal, bool, None, list, tuple, bytes, io.FileIO, io.BufferedReader, ],
                    _configuration: typing.Optional[schemas.Configuration] = None,
                    **kwargs: typing.Union[schemas.AnyTypeSchema, dict, frozendict.frozendict, str, date, datetime, uuid.UUID, int, float, decimal.Decimal, None, list, tuple, bytes],
                ) -> 'data':
                    return super().__new__(
                        cls,
                        *args,
                        _configuration=_configuration,
                        **kwargs,
                    )
            __annotations__ = {
                "type": type,
                "address": address,
                "state_key_hash": state_key_hash,
                "handle": handle,
                "key": key,
                "data": data,
            }
    
    address: MetaOapg.properties.address
    data: MetaOapg.properties.data
    state_key_hash: MetaOapg.properties.state_key_hash
    handle: MetaOapg.properties.handle
    type: MetaOapg.properties.type
    key: MetaOapg.properties.key
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["type"]) -> MetaOapg.properties.type: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["address"]) -> MetaOapg.properties.address: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["state_key_hash"]) -> MetaOapg.properties.state_key_hash: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["handle"]) -> MetaOapg.properties.handle: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["key"]) -> MetaOapg.properties.key: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["data"]) -> MetaOapg.properties.data: ...
    
    @typing.overload
    def __getitem__(self, name: str) -> schemas.UnsetAnyTypeSchema: ...
    
    def __getitem__(self, name: typing.Union[typing_extensions.Literal["type", "address", "state_key_hash", "handle", "key", "data", ], str]):
        # dict_instance[name] accessor
        return super().__getitem__(name)
    
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["type"]) -> MetaOapg.properties.type: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["address"]) -> MetaOapg.properties.address: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["state_key_hash"]) -> MetaOapg.properties.state_key_hash: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["handle"]) -> MetaOapg.properties.handle: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["key"]) -> MetaOapg.properties.key: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["data"]) -> MetaOapg.properties.data: ...
    
    @typing.overload
    def get_item_oapg(self, name: str) -> typing.Union[schemas.UnsetAnyTypeSchema, schemas.Unset]: ...
    
    def get_item_oapg(self, name: typing.Union[typing_extensions.Literal["type", "address", "state_key_hash", "handle", "key", "data", ], str]):
        return super().get_item_oapg(name)
    

    def __new__(
        cls,
        *args: typing.Union[dict, frozendict.frozendict, ],
        address: typing.Union[MetaOapg.properties.address, dict, frozendict.frozendict, ],
        data: typing.Union[MetaOapg.properties.data, dict, frozendict.frozendict, str, date, datetime, uuid.UUID, int, float, decimal.Decimal, bool, None, list, tuple, bytes, io.FileIO, io.BufferedReader, ],
        state_key_hash: typing.Union[MetaOapg.properties.state_key_hash, str, ],
        handle: typing.Union[MetaOapg.properties.handle, dict, frozendict.frozendict, ],
        type: typing.Union[MetaOapg.properties.type, str, ],
        key: typing.Union[MetaOapg.properties.key, dict, frozendict.frozendict, ],
        _configuration: typing.Optional[schemas.Configuration] = None,
        **kwargs: typing.Union[schemas.AnyTypeSchema, dict, frozendict.frozendict, str, date, datetime, uuid.UUID, int, float, decimal.Decimal, None, list, tuple, bytes],
    ) -> 'DeleteTableItemChange':
        return super().__new__(
            cls,
            *args,
            address=address,
            data=data,
            state_key_hash=state_key_hash,
            handle=handle,
            type=type,
            key=key,
            _configuration=_configuration,
            **kwargs,
        )

from openapi_aptos_api.model.deleted_table_data import DeletedTableData



# coding: utf-8

"""
    Streams Api

    API that provides access to Moralis Streams  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""

from datetime import date, datetime  # noqa: F401
import decimal  # noqa: F401
import functools  # noqa: F401
import io  # noqa: F401
import re  # noqa: F401
import typing  # noqa: F401
import typing_extensions  # noqa: F401
import uuid  # noqa: F401

import frozendict  # noqa: F401

from openapi_streams import schemas  # noqa: F401


class StreamsTypesStreamsModel(
    schemas.DictSchema
):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """


    class MetaOapg:
        required = {
            "description",
            "chainIds",
            "id",
            "tag",
            "statusMessage",
            "webhookUrl",
            "status",
        }
        
        class properties:
            webhookUrl = schemas.StrSchema
            description = schemas.StrSchema
            tag = schemas.StrSchema
            
            
            class chainIds(
                schemas.ListSchema
            ):
            
            
                class MetaOapg:
                    items = schemas.StrSchema
            
                def __new__(
                    cls,
                    arg: typing.Union[typing.Tuple[typing.Union[MetaOapg.items, str, ]], typing.List[typing.Union[MetaOapg.items, str, ]]],
                    _configuration: typing.Optional[schemas.Configuration] = None,
                ) -> 'chainIds':
                    return super().__new__(
                        cls,
                        arg,
                        _configuration=_configuration,
                    )
            
                def __getitem__(self, i: int) -> MetaOapg.items:
                    return super().__getitem__(i)
        
            @staticmethod
            def id() -> typing.Type['UUID']:
                return UUID
        
            @staticmethod
            def status() -> typing.Type['StreamsStatus']:
                return StreamsStatus
            statusMessage = schemas.StrSchema
            
            
            class topic0(
                schemas.ListBase,
                schemas.NoneBase,
                schemas.Schema,
                schemas.NoneTupleMixin
            ):
            
            
                class MetaOapg:
                    items = schemas.StrSchema
            
            
                def __new__(
                    cls,
                    *args: typing.Union[list, tuple, None, ],
                    _configuration: typing.Optional[schemas.Configuration] = None,
                ) -> 'topic0':
                    return super().__new__(
                        cls,
                        *args,
                        _configuration=_configuration,
                    )
            allAddresses = schemas.BoolSchema
            includeNativeTxs = schemas.BoolSchema
            includeContractLogs = schemas.BoolSchema
            includeInternalTxs = schemas.BoolSchema
            
            
            class getNativeBalances(
                schemas.ListSchema
            ):
            
            
                class MetaOapg:
                    
                    @staticmethod
                    def items() -> typing.Type['GetNativeBalances']:
                        return GetNativeBalances
            
                def __new__(
                    cls,
                    arg: typing.Union[typing.Tuple['GetNativeBalances'], typing.List['GetNativeBalances']],
                    _configuration: typing.Optional[schemas.Configuration] = None,
                ) -> 'getNativeBalances':
                    return super().__new__(
                        cls,
                        arg,
                        _configuration=_configuration,
                    )
            
                def __getitem__(self, i: int) -> 'GetNativeBalances':
                    return super().__getitem__(i)
            
            
            class abi(
                schemas.ListBase,
                schemas.NoneBase,
                schemas.Schema,
                schemas.NoneTupleMixin
            ):
            
            
                class MetaOapg:
                    
                    @staticmethod
                    def items() -> typing.Type['AbiItem']:
                        return AbiItem
            
            
                def __new__(
                    cls,
                    *args: typing.Union[list, tuple, None, ],
                    _configuration: typing.Optional[schemas.Configuration] = None,
                ) -> 'abi':
                    return super().__new__(
                        cls,
                        *args,
                        _configuration=_configuration,
                    )
            
            
            class advancedOptions(
                schemas.ListBase,
                schemas.NoneBase,
                schemas.Schema,
                schemas.NoneTupleMixin
            ):
            
            
                class MetaOapg:
                    
                    @staticmethod
                    def items() -> typing.Type['AdvancedOptions']:
                        return AdvancedOptions
            
            
                def __new__(
                    cls,
                    *args: typing.Union[list, tuple, None, ],
                    _configuration: typing.Optional[schemas.Configuration] = None,
                ) -> 'advancedOptions':
                    return super().__new__(
                        cls,
                        *args,
                        _configuration=_configuration,
                    )
            demo = schemas.BoolSchema
            
            
            class triggers(
                schemas.ListBase,
                schemas.NoneBase,
                schemas.Schema,
                schemas.NoneTupleMixin
            ):
            
            
                class MetaOapg:
                    
                    @staticmethod
                    def items() -> typing.Type['StreamsTrigger']:
                        return StreamsTrigger
            
            
                def __new__(
                    cls,
                    *args: typing.Union[list, tuple, None, ],
                    _configuration: typing.Optional[schemas.Configuration] = None,
                ) -> 'triggers':
                    return super().__new__(
                        cls,
                        *args,
                        _configuration=_configuration,
                    )
            __annotations__ = {
                "webhookUrl": webhookUrl,
                "description": description,
                "tag": tag,
                "chainIds": chainIds,
                "id": id,
                "status": status,
                "statusMessage": statusMessage,
                "topic0": topic0,
                "allAddresses": allAddresses,
                "includeNativeTxs": includeNativeTxs,
                "includeContractLogs": includeContractLogs,
                "includeInternalTxs": includeInternalTxs,
                "getNativeBalances": getNativeBalances,
                "abi": abi,
                "advancedOptions": advancedOptions,
                "demo": demo,
                "triggers": triggers,
            }
        additional_properties = schemas.NotAnyTypeSchema
    
    description: MetaOapg.properties.description
    chainIds: MetaOapg.properties.chainIds
    id: 'UUID'
    tag: MetaOapg.properties.tag
    statusMessage: MetaOapg.properties.statusMessage
    webhookUrl: MetaOapg.properties.webhookUrl
    status: 'StreamsStatus'
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["description"]) -> MetaOapg.properties.description: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["chainIds"]) -> MetaOapg.properties.chainIds: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["id"]) -> 'UUID': ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["tag"]) -> MetaOapg.properties.tag: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["statusMessage"]) -> MetaOapg.properties.statusMessage: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["webhookUrl"]) -> MetaOapg.properties.webhookUrl: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["status"]) -> 'StreamsStatus': ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["topic0"]) -> MetaOapg.properties.topic0: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["allAddresses"]) -> MetaOapg.properties.allAddresses: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["includeNativeTxs"]) -> MetaOapg.properties.includeNativeTxs: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["includeContractLogs"]) -> MetaOapg.properties.includeContractLogs: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["includeInternalTxs"]) -> MetaOapg.properties.includeInternalTxs: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["getNativeBalances"]) -> MetaOapg.properties.getNativeBalances: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["abi"]) -> MetaOapg.properties.abi: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["advancedOptions"]) -> MetaOapg.properties.advancedOptions: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["demo"]) -> MetaOapg.properties.demo: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["triggers"]) -> MetaOapg.properties.triggers: ...
    
    def __getitem__(self, name: typing.Union[typing_extensions.Literal["description"], typing_extensions.Literal["chainIds"], typing_extensions.Literal["id"], typing_extensions.Literal["tag"], typing_extensions.Literal["statusMessage"], typing_extensions.Literal["webhookUrl"], typing_extensions.Literal["status"], typing_extensions.Literal["topic0"], typing_extensions.Literal["allAddresses"], typing_extensions.Literal["includeNativeTxs"], typing_extensions.Literal["includeContractLogs"], typing_extensions.Literal["includeInternalTxs"], typing_extensions.Literal["getNativeBalances"], typing_extensions.Literal["abi"], typing_extensions.Literal["advancedOptions"], typing_extensions.Literal["demo"], typing_extensions.Literal["triggers"], ]):
        # dict_instance[name] accessor
        return super().__getitem__(name)
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["description"]) -> MetaOapg.properties.description: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["chainIds"]) -> MetaOapg.properties.chainIds: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["id"]) -> 'UUID': ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["tag"]) -> MetaOapg.properties.tag: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["statusMessage"]) -> MetaOapg.properties.statusMessage: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["webhookUrl"]) -> MetaOapg.properties.webhookUrl: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["status"]) -> 'StreamsStatus': ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["topic0"]) -> typing.Union[MetaOapg.properties.topic0, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["allAddresses"]) -> typing.Union[MetaOapg.properties.allAddresses, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["includeNativeTxs"]) -> typing.Union[MetaOapg.properties.includeNativeTxs, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["includeContractLogs"]) -> typing.Union[MetaOapg.properties.includeContractLogs, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["includeInternalTxs"]) -> typing.Union[MetaOapg.properties.includeInternalTxs, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["getNativeBalances"]) -> typing.Union[MetaOapg.properties.getNativeBalances, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["abi"]) -> typing.Union[MetaOapg.properties.abi, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["advancedOptions"]) -> typing.Union[MetaOapg.properties.advancedOptions, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["demo"]) -> typing.Union[MetaOapg.properties.demo, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["triggers"]) -> typing.Union[MetaOapg.properties.triggers, schemas.Unset]: ...
    
    def get_item_oapg(self, name: typing.Union[typing_extensions.Literal["description"], typing_extensions.Literal["chainIds"], typing_extensions.Literal["id"], typing_extensions.Literal["tag"], typing_extensions.Literal["statusMessage"], typing_extensions.Literal["webhookUrl"], typing_extensions.Literal["status"], typing_extensions.Literal["topic0"], typing_extensions.Literal["allAddresses"], typing_extensions.Literal["includeNativeTxs"], typing_extensions.Literal["includeContractLogs"], typing_extensions.Literal["includeInternalTxs"], typing_extensions.Literal["getNativeBalances"], typing_extensions.Literal["abi"], typing_extensions.Literal["advancedOptions"], typing_extensions.Literal["demo"], typing_extensions.Literal["triggers"], ]):
        return super().get_item_oapg(name)

    def __new__(
        cls,
        *args: typing.Union[dict, frozendict.frozendict, ],
        description: typing.Union[MetaOapg.properties.description, str, ],
        chainIds: typing.Union[MetaOapg.properties.chainIds, list, tuple, ],
        id: 'UUID',
        tag: typing.Union[MetaOapg.properties.tag, str, ],
        statusMessage: typing.Union[MetaOapg.properties.statusMessage, str, ],
        webhookUrl: typing.Union[MetaOapg.properties.webhookUrl, str, ],
        status: 'StreamsStatus',
        topic0: typing.Union[MetaOapg.properties.topic0, list, tuple, None, schemas.Unset] = schemas.unset,
        allAddresses: typing.Union[MetaOapg.properties.allAddresses, bool, schemas.Unset] = schemas.unset,
        includeNativeTxs: typing.Union[MetaOapg.properties.includeNativeTxs, bool, schemas.Unset] = schemas.unset,
        includeContractLogs: typing.Union[MetaOapg.properties.includeContractLogs, bool, schemas.Unset] = schemas.unset,
        includeInternalTxs: typing.Union[MetaOapg.properties.includeInternalTxs, bool, schemas.Unset] = schemas.unset,
        getNativeBalances: typing.Union[MetaOapg.properties.getNativeBalances, list, tuple, schemas.Unset] = schemas.unset,
        abi: typing.Union[MetaOapg.properties.abi, list, tuple, None, schemas.Unset] = schemas.unset,
        advancedOptions: typing.Union[MetaOapg.properties.advancedOptions, list, tuple, None, schemas.Unset] = schemas.unset,
        demo: typing.Union[MetaOapg.properties.demo, bool, schemas.Unset] = schemas.unset,
        triggers: typing.Union[MetaOapg.properties.triggers, list, tuple, None, schemas.Unset] = schemas.unset,
        _configuration: typing.Optional[schemas.Configuration] = None,
    ) -> 'StreamsTypesStreamsModel':
        return super().__new__(
            cls,
            *args,
            description=description,
            chainIds=chainIds,
            id=id,
            tag=tag,
            statusMessage=statusMessage,
            webhookUrl=webhookUrl,
            status=status,
            topic0=topic0,
            allAddresses=allAddresses,
            includeNativeTxs=includeNativeTxs,
            includeContractLogs=includeContractLogs,
            includeInternalTxs=includeInternalTxs,
            getNativeBalances=getNativeBalances,
            abi=abi,
            advancedOptions=advancedOptions,
            demo=demo,
            triggers=triggers,
            _configuration=_configuration,
        )

from openapi_streams.model.abi_item import AbiItem
from openapi_streams.model.advanced_options import AdvancedOptions
from openapi_streams.model.get_native_balances import GetNativeBalances
from openapi_streams.model.streams_status import StreamsStatus
from openapi_streams.model.streams_trigger import StreamsTrigger
from openapi_streams.model.uuid import UUID



# coding: utf-8

"""
    Streams Api

    API that provides access to Moralis Streams  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""

from datetime import date, datetime  # noqa: F401
import decimal  # noqa: F401
import functools  # noqa: F401
import io  # noqa: F401
import re  # noqa: F401
import typing  # noqa: F401
import typing_extensions  # noqa: F401
import uuid  # noqa: F401

import frozendict  # noqa: F401

from openapi_streams import schemas  # noqa: F401


class IWebhookDeliveryLogsModel(
    schemas.DictSchema
):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """


    class MetaOapg:
        required = {
            "createdAt",
            "retries",
            "chain",
            "streamId",
            "blockNumber",
            "errorMessage",
            "id",
            "tag",
            "type",
            "deliveryStatus",
            "webhookUrl",
        }
        
        class properties:
        
            @staticmethod
            def id() -> typing.Type['UUID']:
                return UUID
            streamId = schemas.StrSchema
            chain = schemas.StrSchema
            webhookUrl = schemas.StrSchema
            tag = schemas.StrSchema
            retries = schemas.Float64Schema
            
            
            class deliveryStatus(
                schemas.EnumBase,
                schemas.StrSchema
            ):
            
            
                class MetaOapg:
                    enum_value_to_name = {
                        "failed": "FAILED",
                        "success": "SUCCESS",
                    }
                
                @schemas.classproperty
                def FAILED(cls):
                    return cls("failed")
                
                @schemas.classproperty
                def SUCCESS(cls):
                    return cls("success")
            blockNumber = schemas.Float64Schema
            errorMessage = schemas.StrSchema
            
            
            class type(
                schemas.EnumBase,
                schemas.StrSchema
            ):
            
            
                class MetaOapg:
                    enum_value_to_name = {
                        "evm": "EVM",
                        "aptos": "APTOS",
                    }
                
                @schemas.classproperty
                def EVM(cls):
                    return cls("evm")
                
                @schemas.classproperty
                def APTOS(cls):
                    return cls("aptos")
            createdAt = schemas.DateTimeSchema
            __annotations__ = {
                "id": id,
                "streamId": streamId,
                "chain": chain,
                "webhookUrl": webhookUrl,
                "tag": tag,
                "retries": retries,
                "deliveryStatus": deliveryStatus,
                "blockNumber": blockNumber,
                "errorMessage": errorMessage,
                "type": type,
                "createdAt": createdAt,
            }
        additional_properties = schemas.NotAnyTypeSchema
    
    createdAt: MetaOapg.properties.createdAt
    retries: MetaOapg.properties.retries
    chain: MetaOapg.properties.chain
    streamId: MetaOapg.properties.streamId
    blockNumber: MetaOapg.properties.blockNumber
    errorMessage: MetaOapg.properties.errorMessage
    id: 'UUID'
    tag: MetaOapg.properties.tag
    type: MetaOapg.properties.type
    deliveryStatus: MetaOapg.properties.deliveryStatus
    webhookUrl: MetaOapg.properties.webhookUrl
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["createdAt"]) -> MetaOapg.properties.createdAt: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["retries"]) -> MetaOapg.properties.retries: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["chain"]) -> MetaOapg.properties.chain: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["streamId"]) -> MetaOapg.properties.streamId: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["blockNumber"]) -> MetaOapg.properties.blockNumber: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["errorMessage"]) -> MetaOapg.properties.errorMessage: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["id"]) -> 'UUID': ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["tag"]) -> MetaOapg.properties.tag: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["type"]) -> MetaOapg.properties.type: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["deliveryStatus"]) -> MetaOapg.properties.deliveryStatus: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["webhookUrl"]) -> MetaOapg.properties.webhookUrl: ...
    
    def __getitem__(self, name: typing.Union[typing_extensions.Literal["createdAt"], typing_extensions.Literal["retries"], typing_extensions.Literal["chain"], typing_extensions.Literal["streamId"], typing_extensions.Literal["blockNumber"], typing_extensions.Literal["errorMessage"], typing_extensions.Literal["id"], typing_extensions.Literal["tag"], typing_extensions.Literal["type"], typing_extensions.Literal["deliveryStatus"], typing_extensions.Literal["webhookUrl"], ]):
        # dict_instance[name] accessor
        return super().__getitem__(name)
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["createdAt"]) -> MetaOapg.properties.createdAt: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["retries"]) -> MetaOapg.properties.retries: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["chain"]) -> MetaOapg.properties.chain: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["streamId"]) -> MetaOapg.properties.streamId: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["blockNumber"]) -> MetaOapg.properties.blockNumber: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["errorMessage"]) -> MetaOapg.properties.errorMessage: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["id"]) -> 'UUID': ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["tag"]) -> MetaOapg.properties.tag: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["type"]) -> MetaOapg.properties.type: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["deliveryStatus"]) -> MetaOapg.properties.deliveryStatus: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["webhookUrl"]) -> MetaOapg.properties.webhookUrl: ...
    
    def get_item_oapg(self, name: typing.Union[typing_extensions.Literal["createdAt"], typing_extensions.Literal["retries"], typing_extensions.Literal["chain"], typing_extensions.Literal["streamId"], typing_extensions.Literal["blockNumber"], typing_extensions.Literal["errorMessage"], typing_extensions.Literal["id"], typing_extensions.Literal["tag"], typing_extensions.Literal["type"], typing_extensions.Literal["deliveryStatus"], typing_extensions.Literal["webhookUrl"], ]):
        return super().get_item_oapg(name)

    def __new__(
        cls,
        *args: typing.Union[dict, frozendict.frozendict, ],
        createdAt: typing.Union[MetaOapg.properties.createdAt, str, datetime, ],
        retries: typing.Union[MetaOapg.properties.retries, decimal.Decimal, int, float, ],
        chain: typing.Union[MetaOapg.properties.chain, str, ],
        streamId: typing.Union[MetaOapg.properties.streamId, str, ],
        blockNumber: typing.Union[MetaOapg.properties.blockNumber, decimal.Decimal, int, float, ],
        errorMessage: typing.Union[MetaOapg.properties.errorMessage, str, ],
        id: 'UUID',
        tag: typing.Union[MetaOapg.properties.tag, str, ],
        type: typing.Union[MetaOapg.properties.type, str, ],
        deliveryStatus: typing.Union[MetaOapg.properties.deliveryStatus, str, ],
        webhookUrl: typing.Union[MetaOapg.properties.webhookUrl, str, ],
        _configuration: typing.Optional[schemas.Configuration] = None,
    ) -> 'IWebhookDeliveryLogsModel':
        return super().__new__(
            cls,
            *args,
            createdAt=createdAt,
            retries=retries,
            chain=chain,
            streamId=streamId,
            blockNumber=blockNumber,
            errorMessage=errorMessage,
            id=id,
            tag=tag,
            type=type,
            deliveryStatus=deliveryStatus,
            webhookUrl=webhookUrl,
            _configuration=_configuration,
        )

from openapi_streams.model.uuid import UUID



# coding: utf-8

"""
    Streams Api

    API that provides access to Moralis Streams  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""

from datetime import date, datetime  # noqa: F401
import decimal  # noqa: F401
import functools  # noqa: F401
import io  # noqa: F401
import re  # noqa: F401
import typing  # noqa: F401
import typing_extensions  # noqa: F401
import uuid  # noqa: F401

import frozendict  # noqa: F401

from openapi_streams import schemas  # noqa: F401


class StreamsFilter(
    schemas.DictSchema
):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.

    The filter object for the topic0
https://docs.moralis.io/docs/filter-streams
    """


    class MetaOapg:
        additional_properties = schemas.AnyTypeSchema
    
    def __getitem__(self, name: typing.Union[str, ]) -> MetaOapg.additional_properties:
        # dict_instance[name] accessor
        return super().__getitem__(name)
    
    def get_item_oapg(self, name: typing.Union[str, ]) -> MetaOapg.additional_properties:
        return super().get_item_oapg(name)

    def __new__(
        cls,
        *args: typing.Union[dict, frozendict.frozendict, ],
        _configuration: typing.Optional[schemas.Configuration] = None,
        **kwargs: typing.Union[MetaOapg.additional_properties, dict, frozendict.frozendict, str, date, datetime, uuid.UUID, int, float, decimal.Decimal, bool, None, list, tuple, bytes, io.FileIO, io.BufferedReader, ],
    ) -> 'StreamsFilter':
        return super().__new__(
            cls,
            *args,
            _configuration=_configuration,
            **kwargs,
        )



# coding: utf-8

"""
    aptos-api

    The aptos-api provider  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""

from openapi_aptos_api.paths.collections.get import GetNftCollections
from openapi_aptos_api.paths.collections_creators.get import GetNftCollectionsByCreator
from openapi_aptos_api.paths.collections_ids.get import GetNftCollectionsByIds


class CollectionsApi(
    GetNftCollections,
    GetNftCollectionsByCreator,
    GetNftCollectionsByIds,
):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """
    pass



# coding: utf-8

"""
    aptos-api

    The aptos-api provider  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""

from datetime import date, datetime  # noqa: F401
import decimal  # noqa: F401
import functools  # noqa: F401
import io  # noqa: F401
import re  # noqa: F401
import typing  # noqa: F401
import typing_extensions  # noqa: F401
import uuid  # noqa: F401

import frozendict  # noqa: F401

from openapi_aptos_api import schemas  # noqa: F401


class ScriptWriteSet(
    schemas.DictSchema
):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """


    class MetaOapg:
        required = {
            "execute_as",
            "type",
            "script",
        }
        
        class properties:
            type = schemas.StrSchema
            execute_as = schemas.StrSchema
            
            
            class script(
                schemas.ComposedSchema,
            ):
            
            
                class MetaOapg:
                    
                    @classmethod
                    @functools.lru_cache()
                    def all_of(cls):
                        # we need this here to make our import statements work
                        # we must store _composed_schemas in here so the code is only run
                        # when we invoke this method. If we kept this at the class
                        # level we would get an error because the class level
                        # code would be run when this module is imported, and these composed
                        # classes don't exist yet because their module has not finished
                        # loading
                        return [
                            ScriptPayloadRequest,
                        ]
            
            
                def __new__(
                    cls,
                    *args: typing.Union[dict, frozendict.frozendict, str, date, datetime, uuid.UUID, int, float, decimal.Decimal, bool, None, list, tuple, bytes, io.FileIO, io.BufferedReader, ],
                    _configuration: typing.Optional[schemas.Configuration] = None,
                    **kwargs: typing.Union[schemas.AnyTypeSchema, dict, frozendict.frozendict, str, date, datetime, uuid.UUID, int, float, decimal.Decimal, None, list, tuple, bytes],
                ) -> 'script':
                    return super().__new__(
                        cls,
                        *args,
                        _configuration=_configuration,
                        **kwargs,
                    )
            __annotations__ = {
                "type": type,
                "execute_as": execute_as,
                "script": script,
            }
    
    execute_as: MetaOapg.properties.execute_as
    type: MetaOapg.properties.type
    script: MetaOapg.properties.script
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["type"]) -> MetaOapg.properties.type: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["execute_as"]) -> MetaOapg.properties.execute_as: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["script"]) -> MetaOapg.properties.script: ...
    
    @typing.overload
    def __getitem__(self, name: str) -> schemas.UnsetAnyTypeSchema: ...
    
    def __getitem__(self, name: typing.Union[typing_extensions.Literal["type", "execute_as", "script", ], str]):
        # dict_instance[name] accessor
        return super().__getitem__(name)
    
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["type"]) -> MetaOapg.properties.type: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["execute_as"]) -> MetaOapg.properties.execute_as: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["script"]) -> MetaOapg.properties.script: ...
    
    @typing.overload
    def get_item_oapg(self, name: str) -> typing.Union[schemas.UnsetAnyTypeSchema, schemas.Unset]: ...
    
    def get_item_oapg(self, name: typing.Union[typing_extensions.Literal["type", "execute_as", "script", ], str]):
        return super().get_item_oapg(name)
    

    def __new__(
        cls,
        *args: typing.Union[dict, frozendict.frozendict, ],
        execute_as: typing.Union[MetaOapg.properties.execute_as, str, ],
        type: typing.Union[MetaOapg.properties.type, str, ],
        script: typing.Union[MetaOapg.properties.script, dict, frozendict.frozendict, str, date, datetime, uuid.UUID, int, float, decimal.Decimal, bool, None, list, tuple, bytes, io.FileIO, io.BufferedReader, ],
        _configuration: typing.Optional[schemas.Configuration] = None,
        **kwargs: typing.Union[schemas.AnyTypeSchema, dict, frozendict.frozendict, str, date, datetime, uuid.UUID, int, float, decimal.Decimal, None, list, tuple, bytes],
    ) -> 'ScriptWriteSet':
        return super().__new__(
            cls,
            *args,
            execute_as=execute_as,
            type=type,
            script=script,
            _configuration=_configuration,
            **kwargs,
        )

from openapi_aptos_api.model.script_payload_request import ScriptPayloadRequest



# coding: utf-8

"""
    Streams Api

    API that provides access to Moralis Streams  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""

from datetime import date, datetime  # noqa: F401
import decimal  # noqa: F401
import functools  # noqa: F401
import io  # noqa: F401
import re  # noqa: F401
import typing  # noqa: F401
import typing_extensions  # noqa: F401
import uuid  # noqa: F401

import frozendict  # noqa: F401

from openapi_streams import schemas  # noqa: F401


class SettingsRegion(
    schemas.EnumBase,
    schemas.StrSchema
):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """


    class MetaOapg:
        enum_value_to_name = {
            "us-east-1": "USEAST1",
            "us-west-2": "USWEST2",
            "eu-central-1": "EUCENTRAL1",
            "ap-southeast-1": "APSOUTHEAST1",
        }
    
    @schemas.classproperty
    def USEAST1(cls):
        return cls("us-east-1")
    
    @schemas.classproperty
    def USWEST2(cls):
        return cls("us-west-2")
    
    @schemas.classproperty
    def EUCENTRAL1(cls):
        return cls("eu-central-1")
    
    @schemas.classproperty
    def APSOUTHEAST1(cls):
        return cls("ap-southeast-1")



# coding: utf-8

"""
    aptos-api

    The aptos-api provider  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""

from datetime import date, datetime  # noqa: F401
import decimal  # noqa: F401
import functools  # noqa: F401
import io  # noqa: F401
import re  # noqa: F401
import typing  # noqa: F401
import typing_extensions  # noqa: F401
import uuid  # noqa: F401

import frozendict  # noqa: F401

from openapi_aptos_api import schemas  # noqa: F401


class Block(
    schemas.DictSchema
):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """


    class MetaOapg:
        required = {
            "last_version",
            "first_version",
            "block_timestamp",
            "block_hash",
            "block_height",
            "transactions",
        }
        
        class properties:
            block_height = schemas.StrSchema
            block_hash = schemas.StrSchema
            block_timestamp = schemas.StrSchema
            first_version = schemas.StrSchema
            last_version = schemas.StrSchema
            
            
            class transactions(
                schemas.ListSchema
            ):
            
            
                class MetaOapg:
                    
                    
                    class items(
                        schemas.ComposedSchema,
                    ):
                    
                    
                        class MetaOapg:
                            
                            @classmethod
                            @functools.lru_cache()
                            def one_of(cls):
                                # we need this here to make our import statements work
                                # we must store _composed_schemas in here so the code is only run
                                # when we invoke this method. If we kept this at the class
                                # level we would get an error because the class level
                                # code would be run when this module is imported, and these composed
                                # classes don't exist yet because their module has not finished
                                # loading
                                return [
                                    PendingTransaction,
                                    UserTransaction,
                                    GenesisTransaction,
                                    BlockMetadataTransaction,
                                    StateCheckpointTransaction,
                                ]
                    
                    
                        def __new__(
                            cls,
                            *args: typing.Union[dict, frozendict.frozendict, str, date, datetime, uuid.UUID, int, float, decimal.Decimal, bool, None, list, tuple, bytes, io.FileIO, io.BufferedReader, ],
                            _configuration: typing.Optional[schemas.Configuration] = None,
                            **kwargs: typing.Union[schemas.AnyTypeSchema, dict, frozendict.frozendict, str, date, datetime, uuid.UUID, int, float, decimal.Decimal, None, list, tuple, bytes],
                        ) -> 'items':
                            return super().__new__(
                                cls,
                                *args,
                                _configuration=_configuration,
                                **kwargs,
                            )
            
                def __new__(
                    cls,
                    arg: typing.Union[typing.Tuple[typing.Union[MetaOapg.items, dict, frozendict.frozendict, str, date, datetime, uuid.UUID, int, float, decimal.Decimal, bool, None, list, tuple, bytes, io.FileIO, io.BufferedReader, ]], typing.List[typing.Union[MetaOapg.items, dict, frozendict.frozendict, str, date, datetime, uuid.UUID, int, float, decimal.Decimal, bool, None, list, tuple, bytes, io.FileIO, io.BufferedReader, ]]],
                    _configuration: typing.Optional[schemas.Configuration] = None,
                ) -> 'transactions':
                    return super().__new__(
                        cls,
                        arg,
                        _configuration=_configuration,
                    )
            
                def __getitem__(self, i: int) -> MetaOapg.items:
                    return super().__getitem__(i)
            __annotations__ = {
                "block_height": block_height,
                "block_hash": block_hash,
                "block_timestamp": block_timestamp,
                "first_version": first_version,
                "last_version": last_version,
                "transactions": transactions,
            }
    
    last_version: MetaOapg.properties.last_version
    first_version: MetaOapg.properties.first_version
    block_timestamp: MetaOapg.properties.block_timestamp
    block_hash: MetaOapg.properties.block_hash
    block_height: MetaOapg.properties.block_height
    transactions: MetaOapg.properties.transactions
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["block_height"]) -> MetaOapg.properties.block_height: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["block_hash"]) -> MetaOapg.properties.block_hash: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["block_timestamp"]) -> MetaOapg.properties.block_timestamp: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["first_version"]) -> MetaOapg.properties.first_version: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["last_version"]) -> MetaOapg.properties.last_version: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["transactions"]) -> MetaOapg.properties.transactions: ...
    
    @typing.overload
    def __getitem__(self, name: str) -> schemas.UnsetAnyTypeSchema: ...
    
    def __getitem__(self, name: typing.Union[typing_extensions.Literal["block_height", "block_hash", "block_timestamp", "first_version", "last_version", "transactions", ], str]):
        # dict_instance[name] accessor
        return super().__getitem__(name)
    
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["block_height"]) -> MetaOapg.properties.block_height: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["block_hash"]) -> MetaOapg.properties.block_hash: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["block_timestamp"]) -> MetaOapg.properties.block_timestamp: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["first_version"]) -> MetaOapg.properties.first_version: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["last_version"]) -> MetaOapg.properties.last_version: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["transactions"]) -> MetaOapg.properties.transactions: ...
    
    @typing.overload
    def get_item_oapg(self, name: str) -> typing.Union[schemas.UnsetAnyTypeSchema, schemas.Unset]: ...
    
    def get_item_oapg(self, name: typing.Union[typing_extensions.Literal["block_height", "block_hash", "block_timestamp", "first_version", "last_version", "transactions", ], str]):
        return super().get_item_oapg(name)
    

    def __new__(
        cls,
        *args: typing.Union[dict, frozendict.frozendict, ],
        last_version: typing.Union[MetaOapg.properties.last_version, str, ],
        first_version: typing.Union[MetaOapg.properties.first_version, str, ],
        block_timestamp: typing.Union[MetaOapg.properties.block_timestamp, str, ],
        block_hash: typing.Union[MetaOapg.properties.block_hash, str, ],
        block_height: typing.Union[MetaOapg.properties.block_height, str, ],
        transactions: typing.Union[MetaOapg.properties.transactions, list, tuple, ],
        _configuration: typing.Optional[schemas.Configuration] = None,
        **kwargs: typing.Union[schemas.AnyTypeSchema, dict, frozendict.frozendict, str, date, datetime, uuid.UUID, int, float, decimal.Decimal, None, list, tuple, bytes],
    ) -> 'Block':
        return super().__new__(
            cls,
            *args,
            last_version=last_version,
            first_version=first_version,
            block_timestamp=block_timestamp,
            block_hash=block_hash,
            block_height=block_height,
            transactions=transactions,
            _configuration=_configuration,
            **kwargs,
        )

from openapi_aptos_api.model.block_metadata_transaction import BlockMetadataTransaction
from openapi_aptos_api.model.genesis_transaction import GenesisTransaction
from openapi_aptos_api.model.pending_transaction import PendingTransaction
from openapi_aptos_api.model.state_checkpoint_transaction import StateCheckpointTransaction
from openapi_aptos_api.model.user_transaction import UserTransaction



from .aptos_streams_add_addresses import aptos_streams_add_addresses
from .aptos_streams_create import aptos_streams_create
from .aptos_streams_delete import aptos_streams_delete
from .aptos_streams_delete_addresses import aptos_streams_delete_addresses
from .aptos_streams_get import aptos_streams_get
from .aptos_streams_get_addresses import aptos_streams_get_addresses
from .aptos_streams_get_all import aptos_streams_get_all
from .aptos_streams_update import aptos_streams_update
from .aptos_streams_update_status import aptos_streams_update_status



# coding: utf-8

"""
    EVM API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 2.1
    Generated by: https://openapi-generator.tech
"""

from openapi_evm_api.paths.info_endpoint_weights.get import EndpointWeights
from openapi_evm_api.paths.address_function.post import RunContractFunction
from openapi_evm_api.paths.web3_version.get import Web3ApiVersion


class UtilsApi(
    EndpointWeights,
    RunContractFunction,
    Web3ApiVersion,
):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """
    pass



# coding: utf-8

"""
    aptos-api

    The aptos-api provider  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""

from datetime import date, datetime  # noqa: F401
import decimal  # noqa: F401
import functools  # noqa: F401
import io  # noqa: F401
import re  # noqa: F401
import typing  # noqa: F401
import typing_extensions  # noqa: F401
import uuid  # noqa: F401

import frozendict  # noqa: F401

from openapi_aptos_api import schemas  # noqa: F401


class MultiAgentSignatureRequest(
    schemas.DictSchema
):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """


    class MetaOapg:
        required = {
            "secondary_signers",
            "secondary_signer_addresses",
            "sender",
            "type",
        }
        
        class properties:
            type = schemas.StrSchema
            
            
            class sender(
                schemas.ComposedSchema,
            ):
            
            
                class MetaOapg:
                    
                    @classmethod
                    @functools.lru_cache()
                    def one_of(cls):
                        # we need this here to make our import statements work
                        # we must store _composed_schemas in here so the code is only run
                        # when we invoke this method. If we kept this at the class
                        # level we would get an error because the class level
                        # code would be run when this module is imported, and these composed
                        # classes don't exist yet because their module has not finished
                        # loading
                        return [
                            Ed25519SignatureRequest,
                            MultiEd25519SignatureRequest,
                        ]
            
            
                def __new__(
                    cls,
                    *args: typing.Union[dict, frozendict.frozendict, str, date, datetime, uuid.UUID, int, float, decimal.Decimal, bool, None, list, tuple, bytes, io.FileIO, io.BufferedReader, ],
                    _configuration: typing.Optional[schemas.Configuration] = None,
                    **kwargs: typing.Union[schemas.AnyTypeSchema, dict, frozendict.frozendict, str, date, datetime, uuid.UUID, int, float, decimal.Decimal, None, list, tuple, bytes],
                ) -> 'sender':
                    return super().__new__(
                        cls,
                        *args,
                        _configuration=_configuration,
                        **kwargs,
                    )
            
            
            class secondary_signer_addresses(
                schemas.ListSchema
            ):
            
            
                class MetaOapg:
                    items = schemas.StrSchema
            
                def __new__(
                    cls,
                    arg: typing.Union[typing.Tuple[typing.Union[MetaOapg.items, str, ]], typing.List[typing.Union[MetaOapg.items, str, ]]],
                    _configuration: typing.Optional[schemas.Configuration] = None,
                ) -> 'secondary_signer_addresses':
                    return super().__new__(
                        cls,
                        arg,
                        _configuration=_configuration,
                    )
            
                def __getitem__(self, i: int) -> MetaOapg.items:
                    return super().__getitem__(i)
            
            
            class secondary_signers(
                schemas.ListSchema
            ):
            
            
                class MetaOapg:
                    items = schemas.StrSchema
            
                def __new__(
                    cls,
                    arg: typing.Union[typing.Tuple[typing.Union[MetaOapg.items, str, ]], typing.List[typing.Union[MetaOapg.items, str, ]]],
                    _configuration: typing.Optional[schemas.Configuration] = None,
                ) -> 'secondary_signers':
                    return super().__new__(
                        cls,
                        arg,
                        _configuration=_configuration,
                    )
            
                def __getitem__(self, i: int) -> MetaOapg.items:
                    return super().__getitem__(i)
            __annotations__ = {
                "type": type,
                "sender": sender,
                "secondary_signer_addresses": secondary_signer_addresses,
                "secondary_signers": secondary_signers,
            }
    
    secondary_signers: MetaOapg.properties.secondary_signers
    secondary_signer_addresses: MetaOapg.properties.secondary_signer_addresses
    sender: MetaOapg.properties.sender
    type: MetaOapg.properties.type
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["type"]) -> MetaOapg.properties.type: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["sender"]) -> MetaOapg.properties.sender: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["secondary_signer_addresses"]) -> MetaOapg.properties.secondary_signer_addresses: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["secondary_signers"]) -> MetaOapg.properties.secondary_signers: ...
    
    @typing.overload
    def __getitem__(self, name: str) -> schemas.UnsetAnyTypeSchema: ...
    
    def __getitem__(self, name: typing.Union[typing_extensions.Literal["type", "sender", "secondary_signer_addresses", "secondary_signers", ], str]):
        # dict_instance[name] accessor
        return super().__getitem__(name)
    
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["type"]) -> MetaOapg.properties.type: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["sender"]) -> MetaOapg.properties.sender: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["secondary_signer_addresses"]) -> MetaOapg.properties.secondary_signer_addresses: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["secondary_signers"]) -> MetaOapg.properties.secondary_signers: ...
    
    @typing.overload
    def get_item_oapg(self, name: str) -> typing.Union[schemas.UnsetAnyTypeSchema, schemas.Unset]: ...
    
    def get_item_oapg(self, name: typing.Union[typing_extensions.Literal["type", "sender", "secondary_signer_addresses", "secondary_signers", ], str]):
        return super().get_item_oapg(name)
    

    def __new__(
        cls,
        *args: typing.Union[dict, frozendict.frozendict, ],
        secondary_signers: typing.Union[MetaOapg.properties.secondary_signers, list, tuple, ],
        secondary_signer_addresses: typing.Union[MetaOapg.properties.secondary_signer_addresses, list, tuple, ],
        sender: typing.Union[MetaOapg.properties.sender, dict, frozendict.frozendict, str, date, datetime, uuid.UUID, int, float, decimal.Decimal, bool, None, list, tuple, bytes, io.FileIO, io.BufferedReader, ],
        type: typing.Union[MetaOapg.properties.type, str, ],
        _configuration: typing.Optional[schemas.Configuration] = None,
        **kwargs: typing.Union[schemas.AnyTypeSchema, dict, frozendict.frozendict, str, date, datetime, uuid.UUID, int, float, decimal.Decimal, None, list, tuple, bytes],
    ) -> 'MultiAgentSignatureRequest':
        return super().__new__(
            cls,
            *args,
            secondary_signers=secondary_signers,
            secondary_signer_addresses=secondary_signer_addresses,
            sender=sender,
            type=type,
            _configuration=_configuration,
            **kwargs,
        )

from openapi_aptos_api.model.ed25519_signature_request import Ed25519SignatureRequest
from openapi_aptos_api.model.multi_ed25519_signature_request import MultiEd25519SignatureRequest



# coding: utf-8

"""
    aptos-api

    The aptos-api provider  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""

from openapi_aptos_api.paths.coins.get import GetCoinInfoByCoinTypeHashes
from openapi_aptos_api.paths.coins_transfers_blocks.get import GetCoinTransfersByBlockHeights
from openapi_aptos_api.paths.coins_transfers_coin_type.get import GetCoinTransfersByCoinType
from openapi_aptos_api.paths.coins_transfers_wallets.get import GetCoinTransfersByOwnerAddresses
from openapi_aptos_api.paths.coins_creators.get import GetCoinsByCreators
from openapi_aptos_api.paths.coins_names.get import GetCoinsByNameRange
from openapi_aptos_api.paths.coins_symbols.get import GetCoinsBySymbolRange
from openapi_aptos_api.paths.coins_latest.get import GetLatestCoins
from openapi_aptos_api.paths.coins_owners_coin_type_hash_top_holders.get import GetTopHoldersByCoin


class CoinsApi(
    GetCoinInfoByCoinTypeHashes,
    GetCoinTransfersByBlockHeights,
    GetCoinTransfersByCoinType,
    GetCoinTransfersByOwnerAddresses,
    GetCoinsByCreators,
    GetCoinsByNameRange,
    GetCoinsBySymbolRange,
    GetLatestCoins,
    GetTopHoldersByCoin,
):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """
    pass



# do not import all endpoints into this module because that uses a lot of memory and stack frames
# if you need the ability to import all endpoints from this module, import them with
# from openapi_evm_api.paths.block_block_number_or_hash_nft_transfers import Api

from openapi_evm_api.paths import PathValues

path = PathValues.BLOCK_BLOCK_NUMBER_OR_HASH_NFT_TRANSFERS


# coding: utf-8

"""
    Streams Api

    API that provides access to Moralis Streams  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""

from openapi_streams.paths.streams_aptos_id_address.post import AptosStreamsAddAddresses
from openapi_streams.paths.streams_aptos.put import AptosStreamsCreate
from openapi_streams.paths.streams_aptos_id.delete import AptosStreamsDelete
from openapi_streams.paths.streams_aptos_id_address.delete import AptosStreamsDeleteAddresses
from openapi_streams.paths.streams_aptos_id.get import AptosStreamsGet
from openapi_streams.paths.streams_aptos_id_address.get import AptosStreamsGetAddresses
from openapi_streams.paths.streams_aptos.get import AptosStreamsGetAll
from openapi_streams.paths.streams_aptos_id.post import AptosStreamsUpdate
from openapi_streams.paths.streams_aptos_id_status.post import AptosStreamsUpdateStatus


class AptosStreamsApi(
    AptosStreamsAddAddresses,
    AptosStreamsCreate,
    AptosStreamsDelete,
    AptosStreamsDeleteAddresses,
    AptosStreamsGet,
    AptosStreamsGetAddresses,
    AptosStreamsGetAll,
    AptosStreamsUpdate,
    AptosStreamsUpdateStatus,
):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """
    pass



# coding: utf-8

"""
    Streams Api

    API that provides access to Moralis Streams  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""

from datetime import date, datetime  # noqa: F401
import decimal  # noqa: F401
import functools  # noqa: F401
import io  # noqa: F401
import re  # noqa: F401
import typing  # noqa: F401
import typing_extensions  # noqa: F401
import uuid  # noqa: F401

import frozendict  # noqa: F401

from openapi_streams import schemas  # noqa: F401


class StreamsTrigger(
    schemas.DictSchema
):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.

    Trigger
    """


    class MetaOapg:
        required = {
            "contractAddress",
            "functionAbi",
            "type",
        }
        
        class properties:
            
            
            class type(
                schemas.EnumBase,
                schemas.StrSchema
            ):
            
            
                class MetaOapg:
                    enum_value_to_name = {
                        "tx": "TX",
                        "log": "LOG",
                        "erc20transfer": "ERC20TRANSFER",
                        "erc20approval": "ERC20APPROVAL",
                        "nfttransfer": "NFTTRANSFER",
                    }
                
                @schemas.classproperty
                def TX(cls):
                    return cls("tx")
                
                @schemas.classproperty
                def LOG(cls):
                    return cls("log")
                
                @schemas.classproperty
                def ERC20TRANSFER(cls):
                    return cls("erc20transfer")
                
                @schemas.classproperty
                def ERC20APPROVAL(cls):
                    return cls("erc20approval")
                
                @schemas.classproperty
                def NFTTRANSFER(cls):
                    return cls("nfttransfer")
            contractAddress = schemas.StrSchema
        
            @staticmethod
            def functionAbi() -> typing.Type['AbiItem']:
                return AbiItem
            
            
            class inputs(
                schemas.ListSchema
            ):
            
            
                class MetaOapg:
                    
                    
                    class items(
                        schemas.ComposedSchema,
                    ):
                    
                    
                        class MetaOapg:
                            any_of_0 = schemas.StrSchema
                            
                            
                            class any_of_1(
                                schemas.ListSchema
                            ):
                            
                            
                                class MetaOapg:
                                    items = schemas.AnyTypeSchema
                            
                                def __new__(
                                    cls,
                                    arg: typing.Union[typing.Tuple[typing.Union[MetaOapg.items, dict, frozendict.frozendict, str, date, datetime, uuid.UUID, int, float, decimal.Decimal, bool, None, list, tuple, bytes, io.FileIO, io.BufferedReader, ]], typing.List[typing.Union[MetaOapg.items, dict, frozendict.frozendict, str, date, datetime, uuid.UUID, int, float, decimal.Decimal, bool, None, list, tuple, bytes, io.FileIO, io.BufferedReader, ]]],
                                    _configuration: typing.Optional[schemas.Configuration] = None,
                                ) -> 'any_of_1':
                                    return super().__new__(
                                        cls,
                                        arg,
                                        _configuration=_configuration,
                                    )
                            
                                def __getitem__(self, i: int) -> MetaOapg.items:
                                    return super().__getitem__(i)
                            
                            @classmethod
                            @functools.lru_cache()
                            def any_of(cls):
                                # we need this here to make our import statements work
                                # we must store _composed_schemas in here so the code is only run
                                # when we invoke this method. If we kept this at the class
                                # level we would get an error because the class level
                                # code would be run when this module is imported, and these composed
                                # classes don't exist yet because their module has not finished
                                # loading
                                return [
                                    cls.any_of_0,
                                    cls.any_of_1,
                                ]
                    
                    
                        def __new__(
                            cls,
                            *args: typing.Union[dict, frozendict.frozendict, str, date, datetime, uuid.UUID, int, float, decimal.Decimal, bool, None, list, tuple, bytes, io.FileIO, io.BufferedReader, ],
                            _configuration: typing.Optional[schemas.Configuration] = None,
                            **kwargs: typing.Union[schemas.AnyTypeSchema, dict, frozendict.frozendict, str, date, datetime, uuid.UUID, int, float, decimal.Decimal, None, list, tuple, bytes],
                        ) -> 'items':
                            return super().__new__(
                                cls,
                                *args,
                                _configuration=_configuration,
                                **kwargs,
                            )
            
                def __new__(
                    cls,
                    arg: typing.Union[typing.Tuple[typing.Union[MetaOapg.items, dict, frozendict.frozendict, str, date, datetime, uuid.UUID, int, float, decimal.Decimal, bool, None, list, tuple, bytes, io.FileIO, io.BufferedReader, ]], typing.List[typing.Union[MetaOapg.items, dict, frozendict.frozendict, str, date, datetime, uuid.UUID, int, float, decimal.Decimal, bool, None, list, tuple, bytes, io.FileIO, io.BufferedReader, ]]],
                    _configuration: typing.Optional[schemas.Configuration] = None,
                ) -> 'inputs':
                    return super().__new__(
                        cls,
                        arg,
                        _configuration=_configuration,
                    )
            
                def __getitem__(self, i: int) -> MetaOapg.items:
                    return super().__getitem__(i)
            topic0 = schemas.StrSchema
            callFrom = schemas.StrSchema
            __annotations__ = {
                "type": type,
                "contractAddress": contractAddress,
                "functionAbi": functionAbi,
                "inputs": inputs,
                "topic0": topic0,
                "callFrom": callFrom,
            }
        additional_properties = schemas.NotAnyTypeSchema
    
    contractAddress: MetaOapg.properties.contractAddress
    functionAbi: 'AbiItem'
    type: MetaOapg.properties.type
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["contractAddress"]) -> MetaOapg.properties.contractAddress: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["functionAbi"]) -> 'AbiItem': ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["type"]) -> MetaOapg.properties.type: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["inputs"]) -> MetaOapg.properties.inputs: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["topic0"]) -> MetaOapg.properties.topic0: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["callFrom"]) -> MetaOapg.properties.callFrom: ...
    
    def __getitem__(self, name: typing.Union[typing_extensions.Literal["contractAddress"], typing_extensions.Literal["functionAbi"], typing_extensions.Literal["type"], typing_extensions.Literal["inputs"], typing_extensions.Literal["topic0"], typing_extensions.Literal["callFrom"], ]):
        # dict_instance[name] accessor
        return super().__getitem__(name)
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["contractAddress"]) -> MetaOapg.properties.contractAddress: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["functionAbi"]) -> 'AbiItem': ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["type"]) -> MetaOapg.properties.type: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["inputs"]) -> typing.Union[MetaOapg.properties.inputs, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["topic0"]) -> typing.Union[MetaOapg.properties.topic0, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["callFrom"]) -> typing.Union[MetaOapg.properties.callFrom, schemas.Unset]: ...
    
    def get_item_oapg(self, name: typing.Union[typing_extensions.Literal["contractAddress"], typing_extensions.Literal["functionAbi"], typing_extensions.Literal["type"], typing_extensions.Literal["inputs"], typing_extensions.Literal["topic0"], typing_extensions.Literal["callFrom"], ]):
        return super().get_item_oapg(name)

    def __new__(
        cls,
        *args: typing.Union[dict, frozendict.frozendict, ],
        contractAddress: typing.Union[MetaOapg.properties.contractAddress, str, ],
        functionAbi: 'AbiItem',
        type: typing.Union[MetaOapg.properties.type, str, ],
        inputs: typing.Union[MetaOapg.properties.inputs, list, tuple, schemas.Unset] = schemas.unset,
        topic0: typing.Union[MetaOapg.properties.topic0, str, schemas.Unset] = schemas.unset,
        callFrom: typing.Union[MetaOapg.properties.callFrom, str, schemas.Unset] = schemas.unset,
        _configuration: typing.Optional[schemas.Configuration] = None,
    ) -> 'StreamsTrigger':
        return super().__new__(
            cls,
            *args,
            contractAddress=contractAddress,
            functionAbi=functionAbi,
            type=type,
            inputs=inputs,
            topic0=topic0,
            callFrom=callFrom,
            _configuration=_configuration,
        )

from openapi_streams.model.abi_item import AbiItem



# coding: utf-8

"""
    aptos-api

    The aptos-api provider  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""

from openapi_aptos_api.paths.accounts_address.get import GetAccount
from openapi_aptos_api.paths.accounts_address_resource_module_name.get import GetAccountModule
from openapi_aptos_api.paths.accounts_address_modules.get import GetAccountModules
from openapi_aptos_api.paths.accounts_address_resource_resource_type.get import GetAccountResource
from openapi_aptos_api.paths.accounts_address_resources.get import GetAccountResources
from openapi_aptos_api.paths.accounts_address_events_creation_number.get import GetEventsByCreationNumber
from openapi_aptos_api.paths.accounts_address_events_event_handle_field_name.get import GetEventsByEventHandle


class AccountsApi(
    GetAccount,
    GetAccountModule,
    GetAccountModules,
    GetAccountResource,
    GetAccountResources,
    GetEventsByCreationNumber,
    GetEventsByEventHandle,
):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """
    pass



# coding: utf-8

"""
    aptos-api

    The aptos-api provider  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""

from datetime import date, datetime  # noqa: F401
import decimal  # noqa: F401
import functools  # noqa: F401
import io  # noqa: F401
import re  # noqa: F401
import typing  # noqa: F401
import typing_extensions  # noqa: F401
import uuid  # noqa: F401

import frozendict  # noqa: F401

from openapi_aptos_api import schemas  # noqa: F401


class CoinInfoDto(
    schemas.DictSchema
):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """


    class MetaOapg:
        required = {
            "supply_aggregator_table_handle",
            "symbol",
            "transaction_version_created",
            "coin_type_hash",
            "coin_type",
            "decimals",
            "transaction_created_timestamp",
            "name",
            "creator_address",
            "supply_aggregator_table_key",
        }
        
        class properties:
            
            
            class coin_type(
                schemas.StrSchema
            ):
            
            
                class MetaOapg:
                    max_length = 5000
                    min_length = 1
            
            
            class coin_type_hash(
                schemas.StrSchema
            ):
            
            
                class MetaOapg:
                    max_length = 64
                    min_length = 64
            
            
            class creator_address(
                schemas.StrSchema
            ):
            
            
                class MetaOapg:
                    max_length = 66
                    min_length = 66
            decimals = schemas.NumberSchema
            
            
            class name(
                schemas.StrSchema
            ):
            
            
                class MetaOapg:
                    max_length = 32
                    min_length = 1
            supply_aggregator_table_handle = schemas.StrSchema
            supply_aggregator_table_key = schemas.StrSchema
            
            
            class symbol(
                schemas.StrSchema
            ):
            
            
                class MetaOapg:
                    max_length = 10
                    min_length = 1
            transaction_created_timestamp = schemas.StrSchema
            transaction_version_created = schemas.StrSchema
            __annotations__ = {
                "coin_type": coin_type,
                "coin_type_hash": coin_type_hash,
                "creator_address": creator_address,
                "decimals": decimals,
                "name": name,
                "supply_aggregator_table_handle": supply_aggregator_table_handle,
                "supply_aggregator_table_key": supply_aggregator_table_key,
                "symbol": symbol,
                "transaction_created_timestamp": transaction_created_timestamp,
                "transaction_version_created": transaction_version_created,
            }
    
    supply_aggregator_table_handle: MetaOapg.properties.supply_aggregator_table_handle
    symbol: MetaOapg.properties.symbol
    transaction_version_created: MetaOapg.properties.transaction_version_created
    coin_type_hash: MetaOapg.properties.coin_type_hash
    coin_type: MetaOapg.properties.coin_type
    decimals: MetaOapg.properties.decimals
    transaction_created_timestamp: MetaOapg.properties.transaction_created_timestamp
    name: MetaOapg.properties.name
    creator_address: MetaOapg.properties.creator_address
    supply_aggregator_table_key: MetaOapg.properties.supply_aggregator_table_key
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["coin_type"]) -> MetaOapg.properties.coin_type: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["coin_type_hash"]) -> MetaOapg.properties.coin_type_hash: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["creator_address"]) -> MetaOapg.properties.creator_address: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["decimals"]) -> MetaOapg.properties.decimals: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["name"]) -> MetaOapg.properties.name: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["supply_aggregator_table_handle"]) -> MetaOapg.properties.supply_aggregator_table_handle: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["supply_aggregator_table_key"]) -> MetaOapg.properties.supply_aggregator_table_key: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["symbol"]) -> MetaOapg.properties.symbol: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["transaction_created_timestamp"]) -> MetaOapg.properties.transaction_created_timestamp: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["transaction_version_created"]) -> MetaOapg.properties.transaction_version_created: ...
    
    @typing.overload
    def __getitem__(self, name: str) -> schemas.UnsetAnyTypeSchema: ...
    
    def __getitem__(self, name: typing.Union[typing_extensions.Literal["coin_type", "coin_type_hash", "creator_address", "decimals", "name", "supply_aggregator_table_handle", "supply_aggregator_table_key", "symbol", "transaction_created_timestamp", "transaction_version_created", ], str]):
        # dict_instance[name] accessor
        return super().__getitem__(name)
    
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["coin_type"]) -> MetaOapg.properties.coin_type: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["coin_type_hash"]) -> MetaOapg.properties.coin_type_hash: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["creator_address"]) -> MetaOapg.properties.creator_address: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["decimals"]) -> MetaOapg.properties.decimals: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["name"]) -> MetaOapg.properties.name: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["supply_aggregator_table_handle"]) -> MetaOapg.properties.supply_aggregator_table_handle: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["supply_aggregator_table_key"]) -> MetaOapg.properties.supply_aggregator_table_key: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["symbol"]) -> MetaOapg.properties.symbol: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["transaction_created_timestamp"]) -> MetaOapg.properties.transaction_created_timestamp: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["transaction_version_created"]) -> MetaOapg.properties.transaction_version_created: ...
    
    @typing.overload
    def get_item_oapg(self, name: str) -> typing.Union[schemas.UnsetAnyTypeSchema, schemas.Unset]: ...
    
    def get_item_oapg(self, name: typing.Union[typing_extensions.Literal["coin_type", "coin_type_hash", "creator_address", "decimals", "name", "supply_aggregator_table_handle", "supply_aggregator_table_key", "symbol", "transaction_created_timestamp", "transaction_version_created", ], str]):
        return super().get_item_oapg(name)
    

    def __new__(
        cls,
        *args: typing.Union[dict, frozendict.frozendict, ],
        supply_aggregator_table_handle: typing.Union[MetaOapg.properties.supply_aggregator_table_handle, str, ],
        symbol: typing.Union[MetaOapg.properties.symbol, str, ],
        transaction_version_created: typing.Union[MetaOapg.properties.transaction_version_created, str, ],
        coin_type_hash: typing.Union[MetaOapg.properties.coin_type_hash, str, ],
        coin_type: typing.Union[MetaOapg.properties.coin_type, str, ],
        decimals: typing.Union[MetaOapg.properties.decimals, decimal.Decimal, int, float, ],
        transaction_created_timestamp: typing.Union[MetaOapg.properties.transaction_created_timestamp, str, ],
        name: typing.Union[MetaOapg.properties.name, str, ],
        creator_address: typing.Union[MetaOapg.properties.creator_address, str, ],
        supply_aggregator_table_key: typing.Union[MetaOapg.properties.supply_aggregator_table_key, str, ],
        _configuration: typing.Optional[schemas.Configuration] = None,
        **kwargs: typing.Union[schemas.AnyTypeSchema, dict, frozendict.frozendict, str, date, datetime, uuid.UUID, int, float, decimal.Decimal, None, list, tuple, bytes],
    ) -> 'CoinInfoDto':
        return super().__new__(
            cls,
            *args,
            supply_aggregator_table_handle=supply_aggregator_table_handle,
            symbol=symbol,
            transaction_version_created=transaction_version_created,
            coin_type_hash=coin_type_hash,
            coin_type=coin_type,
            decimals=decimals,
            transaction_created_timestamp=transaction_created_timestamp,
            name=name,
            creator_address=creator_address,
            supply_aggregator_table_key=supply_aggregator_table_key,
            _configuration=_configuration,
            **kwargs,
        )



# coding: utf-8

"""
    Solana API

    Moralis Solana API  # noqa: E501

    The version of the OpenAPI document: 1.0
    Generated by: https://openapi-generator.tech
"""

from openapi_sol_api.paths.token_network_address_price.get import GetTokenPrice


class TokenApi(
    GetTokenPrice,
):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """
    pass



# coding: utf-8

"""
    EVM API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 2.1
    Generated by: https://openapi-generator.tech
"""

from openapi_evm_api.paths.nft_address.get import GetContractNfts
from openapi_evm_api.paths.nft_get_multiple_nfts.post import GetMultipleNfts
from openapi_evm_api.paths.nft_address_metadata.get import GetNftContractMetadata
from openapi_evm_api.paths.nft_address_transfers.get import GetNftContractTransfers
from openapi_evm_api.paths.nft_address_lowestprice.get import GetNftLowestPrice
from openapi_evm_api.paths.nft_address_token_id.get import GetNftMetadata
from openapi_evm_api.paths.nft_address_owners.get import GetNftOwners
from openapi_evm_api.paths.nft_address_token_id_owners.get import GetNftTokenIdOwners
from openapi_evm_api.paths.nft_address_trades.get import GetNftTrades
from openapi_evm_api.paths.nft_address_token_id_transfers.get import GetNftTransfers
from openapi_evm_api.paths.block_block_number_or_hash_nft_transfers.get import GetNftTransfersByBlock
from openapi_evm_api.paths.nft_transfers.get import GetNftTransfersFromToBlock
from openapi_evm_api.paths.address_nft_collections.get import GetWalletNftCollections
from openapi_evm_api.paths.address_nft_transfers.get import GetWalletNftTransfers
from openapi_evm_api.paths.address_nft.get import GetWalletNfts
from openapi_evm_api.paths.nft_address_token_id_metadata_resync.get import ReSyncMetadata
from openapi_evm_api.paths.nft_search.get import SearchNfts
from openapi_evm_api.paths.nft_address_sync.put import SyncNftContract


class NftApi(
    GetContractNfts,
    GetMultipleNfts,
    GetNftContractMetadata,
    GetNftContractTransfers,
    GetNftLowestPrice,
    GetNftMetadata,
    GetNftOwners,
    GetNftTokenIdOwners,
    GetNftTrades,
    GetNftTransfers,
    GetNftTransfersByBlock,
    GetNftTransfersFromToBlock,
    GetWalletNftCollections,
    GetWalletNftTransfers,
    GetWalletNfts,
    ReSyncMetadata,
    SearchNfts,
    SyncNftContract,
):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """
    pass



import typing_extensions

from openapi_evm_api.apis.tags import TagValues
from openapi_evm_api.apis.tags.balance_api import BalanceApi
from openapi_evm_api.apis.tags.block_api import BlockApi
from openapi_evm_api.apis.tags.default_api import DefaultApi
from openapi_evm_api.apis.tags.defi_api import DefiApi
from openapi_evm_api.apis.tags.events_api import EventsApi
from openapi_evm_api.apis.tags.ipfs_api import IpfsApi
from openapi_evm_api.apis.tags.nft_api import NftApi
from openapi_evm_api.apis.tags.resolve_api import ResolveApi
from openapi_evm_api.apis.tags.token_api import TokenApi
from openapi_evm_api.apis.tags.transaction_api import TransactionApi
from openapi_evm_api.apis.tags.utils_api import UtilsApi

TagToApi = typing_extensions.TypedDict(
    'TagToApi',
    {
        TagValues.BALANCE: BalanceApi,
        TagValues.BLOCK: BlockApi,
        TagValues.DEFAULT: DefaultApi,
        TagValues.DEFI: DefiApi,
        TagValues.EVENTS: EventsApi,
        TagValues.IPFS: IpfsApi,
        TagValues.NFT: NftApi,
        TagValues.RESOLVE: ResolveApi,
        TagValues.TOKEN: TokenApi,
        TagValues.TRANSACTION: TransactionApi,
        TagValues.UTILS: UtilsApi,
    }
)

tag_to_api = TagToApi(
    {
        TagValues.BALANCE: BalanceApi,
        TagValues.BLOCK: BlockApi,
        TagValues.DEFAULT: DefaultApi,
        TagValues.DEFI: DefiApi,
        TagValues.EVENTS: EventsApi,
        TagValues.IPFS: IpfsApi,
        TagValues.NFT: NftApi,
        TagValues.RESOLVE: ResolveApi,
        TagValues.TOKEN: TokenApi,
        TagValues.TRANSACTION: TransactionApi,
        TagValues.UTILS: UtilsApi,
    }
)




from setuptools import setup, find_packages

REQUIRES = [
    "certifi >= 14.5.14",
    "frozendict ~= 2.3.4",
    "python-dateutil ~= 2.7.0",
    "typing_extensions ~= 4.3.0",
    "urllib3 ~= 1.26.7",
]

setup(
    name="moralis",
    version="0.1.25",
    description="The official Moralis Python SDK",
    keywords=["Moralis", "Moralis SDK", "Moralis Python SDK", "Web3", "Crypto", "Ethereum", "Avalanche",
              "Blockchain", "Contracts", "Eth", "Evm", "Fantom", "Nft", "Dapps", "Binance", "Solana"],
    python_requires=">=3.7",
    install_requires=REQUIRES,
    package_dir={'': 'src'},
    packages=find_packages('src'),
    long_description=open('README.md').read(),
    long_description_content_type='text/markdown',
)



# coding: utf-8

# flake8: noqa

"""
    Streams Api

    API that provides access to Moralis Streams  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""

__version__ = "1.0.0"

# import ApiClient
from openapi_streams.api_client import ApiClient

# import Configuration
from openapi_streams.configuration import Configuration

# import exceptions
from openapi_streams.exceptions import OpenApiException
from openapi_streams.exceptions import ApiAttributeError
from openapi_streams.exceptions import ApiTypeError
from openapi_streams.exceptions import ApiValueError
from openapi_streams.exceptions import ApiKeyError
from openapi_streams.exceptions import ApiException



# coding: utf-8

"""
    Streams Api

    API that provides access to Moralis Streams  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""

from datetime import date, datetime  # noqa: F401
import decimal  # noqa: F401
import functools  # noqa: F401
import io  # noqa: F401
import re  # noqa: F401
import typing  # noqa: F401
import typing_extensions  # noqa: F401
import uuid  # noqa: F401

import frozendict  # noqa: F401

from openapi_streams import schemas  # noqa: F401


class WebhookTypesAptosWebhook(
    schemas.DictSchema
):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """


    class MetaOapg:
        required = {
            "retries",
            "streamId",
            "payloads",
            "changes",
            "coinTransfers",
            "block",
            "tag",
            "coinWithdrawals",
            "transactions",
            "events",
            "coinDeposits",
            "network",
        }
        
        class properties:
        
            @staticmethod
            def block() -> typing.Type['AptosBlock']:
                return AptosBlock
            
            
            class changes(
                schemas.ListSchema
            ):
            
            
                class MetaOapg:
                    items = schemas.AnyTypeSchema
            
                def __new__(
                    cls,
                    arg: typing.Union[typing.Tuple[typing.Union[MetaOapg.items, dict, frozendict.frozendict, str, date, datetime, uuid.UUID, int, float, decimal.Decimal, bool, None, list, tuple, bytes, io.FileIO, io.BufferedReader, ]], typing.List[typing.Union[MetaOapg.items, dict, frozendict.frozendict, str, date, datetime, uuid.UUID, int, float, decimal.Decimal, bool, None, list, tuple, bytes, io.FileIO, io.BufferedReader, ]]],
                    _configuration: typing.Optional[schemas.Configuration] = None,
                ) -> 'changes':
                    return super().__new__(
                        cls,
                        arg,
                        _configuration=_configuration,
                    )
            
                def __getitem__(self, i: int) -> MetaOapg.items:
                    return super().__getitem__(i)
            
            
            class coinDeposits(
                schemas.ListSchema
            ):
            
            
                class MetaOapg:
                    
                    @staticmethod
                    def items() -> typing.Type['AptosCoinDeposit']:
                        return AptosCoinDeposit
            
                def __new__(
                    cls,
                    arg: typing.Union[typing.Tuple['AptosCoinDeposit'], typing.List['AptosCoinDeposit']],
                    _configuration: typing.Optional[schemas.Configuration] = None,
                ) -> 'coinDeposits':
                    return super().__new__(
                        cls,
                        arg,
                        _configuration=_configuration,
                    )
            
                def __getitem__(self, i: int) -> 'AptosCoinDeposit':
                    return super().__getitem__(i)
            
            
            class coinTransfers(
                schemas.ListSchema
            ):
            
            
                class MetaOapg:
                    
                    @staticmethod
                    def items() -> typing.Type['AptosCoinTransfer']:
                        return AptosCoinTransfer
            
                def __new__(
                    cls,
                    arg: typing.Union[typing.Tuple['AptosCoinTransfer'], typing.List['AptosCoinTransfer']],
                    _configuration: typing.Optional[schemas.Configuration] = None,
                ) -> 'coinTransfers':
                    return super().__new__(
                        cls,
                        arg,
                        _configuration=_configuration,
                    )
            
                def __getitem__(self, i: int) -> 'AptosCoinTransfer':
                    return super().__getitem__(i)
            
            
            class coinWithdrawals(
                schemas.ListSchema
            ):
            
            
                class MetaOapg:
                    
                    @staticmethod
                    def items() -> typing.Type['AptosCoinWithdrawal']:
                        return AptosCoinWithdrawal
            
                def __new__(
                    cls,
                    arg: typing.Union[typing.Tuple['AptosCoinWithdrawal'], typing.List['AptosCoinWithdrawal']],
                    _configuration: typing.Optional[schemas.Configuration] = None,
                ) -> 'coinWithdrawals':
                    return super().__new__(
                        cls,
                        arg,
                        _configuration=_configuration,
                    )
            
                def __getitem__(self, i: int) -> 'AptosCoinWithdrawal':
                    return super().__getitem__(i)
            
            
            class events(
                schemas.ListSchema
            ):
            
            
                class MetaOapg:
                    items = schemas.AnyTypeSchema
            
                def __new__(
                    cls,
                    arg: typing.Union[typing.Tuple[typing.Union[MetaOapg.items, dict, frozendict.frozendict, str, date, datetime, uuid.UUID, int, float, decimal.Decimal, bool, None, list, tuple, bytes, io.FileIO, io.BufferedReader, ]], typing.List[typing.Union[MetaOapg.items, dict, frozendict.frozendict, str, date, datetime, uuid.UUID, int, float, decimal.Decimal, bool, None, list, tuple, bytes, io.FileIO, io.BufferedReader, ]]],
                    _configuration: typing.Optional[schemas.Configuration] = None,
                ) -> 'events':
                    return super().__new__(
                        cls,
                        arg,
                        _configuration=_configuration,
                    )
            
                def __getitem__(self, i: int) -> MetaOapg.items:
                    return super().__getitem__(i)
            
            
            class network(
                schemas.EnumBase,
                schemas.StrSchema
            ):
            
            
                class MetaOapg:
                    enum_value_to_name = {
                        "mainnet": "MAINNET",
                        "testnet": "TESTNET",
                    }
                
                @schemas.classproperty
                def MAINNET(cls):
                    return cls("mainnet")
                
                @schemas.classproperty
                def TESTNET(cls):
                    return cls("testnet")
            
            
            class payloads(
                schemas.ListSchema
            ):
            
            
                class MetaOapg:
                    items = schemas.AnyTypeSchema
            
                def __new__(
                    cls,
                    arg: typing.Union[typing.Tuple[typing.Union[MetaOapg.items, dict, frozendict.frozendict, str, date, datetime, uuid.UUID, int, float, decimal.Decimal, bool, None, list, tuple, bytes, io.FileIO, io.BufferedReader, ]], typing.List[typing.Union[MetaOapg.items, dict, frozendict.frozendict, str, date, datetime, uuid.UUID, int, float, decimal.Decimal, bool, None, list, tuple, bytes, io.FileIO, io.BufferedReader, ]]],
                    _configuration: typing.Optional[schemas.Configuration] = None,
                ) -> 'payloads':
                    return super().__new__(
                        cls,
                        arg,
                        _configuration=_configuration,
                    )
            
                def __getitem__(self, i: int) -> MetaOapg.items:
                    return super().__getitem__(i)
            retries = schemas.Float64Schema
            streamId = schemas.StrSchema
            tag = schemas.StrSchema
            
            
            class transactions(
                schemas.ListSchema
            ):
            
            
                class MetaOapg:
                    
                    @staticmethod
                    def items() -> typing.Type['AptosTransaction']:
                        return AptosTransaction
            
                def __new__(
                    cls,
                    arg: typing.Union[typing.Tuple['AptosTransaction'], typing.List['AptosTransaction']],
                    _configuration: typing.Optional[schemas.Configuration] = None,
                ) -> 'transactions':
                    return super().__new__(
                        cls,
                        arg,
                        _configuration=_configuration,
                    )
            
                def __getitem__(self, i: int) -> 'AptosTransaction':
                    return super().__getitem__(i)
            __annotations__ = {
                "block": block,
                "changes": changes,
                "coinDeposits": coinDeposits,
                "coinTransfers": coinTransfers,
                "coinWithdrawals": coinWithdrawals,
                "events": events,
                "network": network,
                "payloads": payloads,
                "retries": retries,
                "streamId": streamId,
                "tag": tag,
                "transactions": transactions,
            }
        additional_properties = schemas.NotAnyTypeSchema
    
    retries: MetaOapg.properties.retries
    streamId: MetaOapg.properties.streamId
    payloads: MetaOapg.properties.payloads
    changes: MetaOapg.properties.changes
    coinTransfers: MetaOapg.properties.coinTransfers
    block: 'AptosBlock'
    tag: MetaOapg.properties.tag
    coinWithdrawals: MetaOapg.properties.coinWithdrawals
    transactions: MetaOapg.properties.transactions
    events: MetaOapg.properties.events
    coinDeposits: MetaOapg.properties.coinDeposits
    network: MetaOapg.properties.network
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["retries"]) -> MetaOapg.properties.retries: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["streamId"]) -> MetaOapg.properties.streamId: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["payloads"]) -> MetaOapg.properties.payloads: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["changes"]) -> MetaOapg.properties.changes: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["coinTransfers"]) -> MetaOapg.properties.coinTransfers: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["block"]) -> 'AptosBlock': ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["tag"]) -> MetaOapg.properties.tag: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["coinWithdrawals"]) -> MetaOapg.properties.coinWithdrawals: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["transactions"]) -> MetaOapg.properties.transactions: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["events"]) -> MetaOapg.properties.events: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["coinDeposits"]) -> MetaOapg.properties.coinDeposits: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["network"]) -> MetaOapg.properties.network: ...
    
    def __getitem__(self, name: typing.Union[typing_extensions.Literal["retries"], typing_extensions.Literal["streamId"], typing_extensions.Literal["payloads"], typing_extensions.Literal["changes"], typing_extensions.Literal["coinTransfers"], typing_extensions.Literal["block"], typing_extensions.Literal["tag"], typing_extensions.Literal["coinWithdrawals"], typing_extensions.Literal["transactions"], typing_extensions.Literal["events"], typing_extensions.Literal["coinDeposits"], typing_extensions.Literal["network"], ]):
        # dict_instance[name] accessor
        return super().__getitem__(name)
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["retries"]) -> MetaOapg.properties.retries: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["streamId"]) -> MetaOapg.properties.streamId: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["payloads"]) -> MetaOapg.properties.payloads: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["changes"]) -> MetaOapg.properties.changes: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["coinTransfers"]) -> MetaOapg.properties.coinTransfers: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["block"]) -> 'AptosBlock': ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["tag"]) -> MetaOapg.properties.tag: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["coinWithdrawals"]) -> MetaOapg.properties.coinWithdrawals: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["transactions"]) -> MetaOapg.properties.transactions: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["events"]) -> MetaOapg.properties.events: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["coinDeposits"]) -> MetaOapg.properties.coinDeposits: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["network"]) -> MetaOapg.properties.network: ...
    
    def get_item_oapg(self, name: typing.Union[typing_extensions.Literal["retries"], typing_extensions.Literal["streamId"], typing_extensions.Literal["payloads"], typing_extensions.Literal["changes"], typing_extensions.Literal["coinTransfers"], typing_extensions.Literal["block"], typing_extensions.Literal["tag"], typing_extensions.Literal["coinWithdrawals"], typing_extensions.Literal["transactions"], typing_extensions.Literal["events"], typing_extensions.Literal["coinDeposits"], typing_extensions.Literal["network"], ]):
        return super().get_item_oapg(name)

    def __new__(
        cls,
        *args: typing.Union[dict, frozendict.frozendict, ],
        retries: typing.Union[MetaOapg.properties.retries, decimal.Decimal, int, float, ],
        streamId: typing.Union[MetaOapg.properties.streamId, str, ],
        payloads: typing.Union[MetaOapg.properties.payloads, list, tuple, ],
        changes: typing.Union[MetaOapg.properties.changes, list, tuple, ],
        coinTransfers: typing.Union[MetaOapg.properties.coinTransfers, list, tuple, ],
        block: 'AptosBlock',
        tag: typing.Union[MetaOapg.properties.tag, str, ],
        coinWithdrawals: typing.Union[MetaOapg.properties.coinWithdrawals, list, tuple, ],
        transactions: typing.Union[MetaOapg.properties.transactions, list, tuple, ],
        events: typing.Union[MetaOapg.properties.events, list, tuple, ],
        coinDeposits: typing.Union[MetaOapg.properties.coinDeposits, list, tuple, ],
        network: typing.Union[MetaOapg.properties.network, str, ],
        _configuration: typing.Optional[schemas.Configuration] = None,
    ) -> 'WebhookTypesAptosWebhook':
        return super().__new__(
            cls,
            *args,
            retries=retries,
            streamId=streamId,
            payloads=payloads,
            changes=changes,
            coinTransfers=coinTransfers,
            block=block,
            tag=tag,
            coinWithdrawals=coinWithdrawals,
            transactions=transactions,
            events=events,
            coinDeposits=coinDeposits,
            network=network,
            _configuration=_configuration,
        )

from openapi_streams.model.aptos_block import AptosBlock
from openapi_streams.model.aptos_coin_deposit import AptosCoinDeposit
from openapi_streams.model.aptos_coin_transfer import AptosCoinTransfer
from openapi_streams.model.aptos_coin_withdrawal import AptosCoinWithdrawal
from openapi_streams.model.aptos_transaction import AptosTransaction



# coding: utf-8

"""
    Solana API

    Moralis Solana API  # noqa: E501

    The version of the OpenAPI document: 1.0
    Generated by: https://openapi-generator.tech
"""

from datetime import date, datetime  # noqa: F401
import decimal  # noqa: F401
import functools  # noqa: F401
import io  # noqa: F401
import re  # noqa: F401
import typing  # noqa: F401
import typing_extensions  # noqa: F401
import uuid  # noqa: F401

import frozendict  # noqa: F401

from openapi_sol_api import schemas  # noqa: F401


class MetaplexNFT(
    schemas.DictSchema
):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """


    class MetaOapg:
        required = {
            "isMutable",
            "updateAuthority",
            "primarySaleHappened",
            "sellerFeeBasisPoints",
            "metadataUri",
            "masterEdition",
        }
        
        class properties:
            metadataUri = schemas.StrSchema
            masterEdition = schemas.BoolSchema
            isMutable = schemas.BoolSchema
            primarySaleHappened = schemas.BoolSchema
            sellerFeeBasisPoints = schemas.NumberSchema
            updateAuthority = schemas.StrSchema
            __annotations__ = {
                "metadataUri": metadataUri,
                "masterEdition": masterEdition,
                "isMutable": isMutable,
                "primarySaleHappened": primarySaleHappened,
                "sellerFeeBasisPoints": sellerFeeBasisPoints,
                "updateAuthority": updateAuthority,
            }
    
    isMutable: MetaOapg.properties.isMutable
    updateAuthority: MetaOapg.properties.updateAuthority
    primarySaleHappened: MetaOapg.properties.primarySaleHappened
    sellerFeeBasisPoints: MetaOapg.properties.sellerFeeBasisPoints
    metadataUri: MetaOapg.properties.metadataUri
    masterEdition: MetaOapg.properties.masterEdition
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["metadataUri"]) -> MetaOapg.properties.metadataUri: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["masterEdition"]) -> MetaOapg.properties.masterEdition: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["isMutable"]) -> MetaOapg.properties.isMutable: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["primarySaleHappened"]) -> MetaOapg.properties.primarySaleHappened: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["sellerFeeBasisPoints"]) -> MetaOapg.properties.sellerFeeBasisPoints: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["updateAuthority"]) -> MetaOapg.properties.updateAuthority: ...
    
    @typing.overload
    def __getitem__(self, name: str) -> schemas.UnsetAnyTypeSchema: ...
    
    def __getitem__(self, name: typing.Union[typing_extensions.Literal["metadataUri", "masterEdition", "isMutable", "primarySaleHappened", "sellerFeeBasisPoints", "updateAuthority", ], str]):
        # dict_instance[name] accessor
        return super().__getitem__(name)
    
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["metadataUri"]) -> MetaOapg.properties.metadataUri: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["masterEdition"]) -> MetaOapg.properties.masterEdition: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["isMutable"]) -> MetaOapg.properties.isMutable: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["primarySaleHappened"]) -> MetaOapg.properties.primarySaleHappened: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["sellerFeeBasisPoints"]) -> MetaOapg.properties.sellerFeeBasisPoints: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["updateAuthority"]) -> MetaOapg.properties.updateAuthority: ...
    
    @typing.overload
    def get_item_oapg(self, name: str) -> typing.Union[schemas.UnsetAnyTypeSchema, schemas.Unset]: ...
    
    def get_item_oapg(self, name: typing.Union[typing_extensions.Literal["metadataUri", "masterEdition", "isMutable", "primarySaleHappened", "sellerFeeBasisPoints", "updateAuthority", ], str]):
        return super().get_item_oapg(name)
    

    def __new__(
        cls,
        *args: typing.Union[dict, frozendict.frozendict, ],
        isMutable: typing.Union[MetaOapg.properties.isMutable, bool, ],
        updateAuthority: typing.Union[MetaOapg.properties.updateAuthority, str, ],
        primarySaleHappened: typing.Union[MetaOapg.properties.primarySaleHappened, bool, ],
        sellerFeeBasisPoints: typing.Union[MetaOapg.properties.sellerFeeBasisPoints, decimal.Decimal, int, float, ],
        metadataUri: typing.Union[MetaOapg.properties.metadataUri, str, ],
        masterEdition: typing.Union[MetaOapg.properties.masterEdition, bool, ],
        _configuration: typing.Optional[schemas.Configuration] = None,
        **kwargs: typing.Union[schemas.AnyTypeSchema, dict, frozendict.frozendict, str, date, datetime, uuid.UUID, int, float, decimal.Decimal, None, list, tuple, bytes],
    ) -> 'MetaplexNFT':
        return super().__new__(
            cls,
            *args,
            isMutable=isMutable,
            updateAuthority=updateAuthority,
            primarySaleHappened=primarySaleHappened,
            sellerFeeBasisPoints=sellerFeeBasisPoints,
            metadataUri=metadataUri,
            masterEdition=masterEdition,
            _configuration=_configuration,
            **kwargs,
        )
